# coding:utf-8
from __future__ import print_function

import json

from volcengine.example.rtc.RtcService import RtcService

if __name__ == '__main__':
    # using your own AK and SK
    AK = 'Your_AK'
    SK = 'Your_SK'

    # Firstly , init an RTCService Class
    rtc_service = RtcService()

    # Then , Set your AK and SK
    rtc_service.set_ak(AK)
    rtc_service.set_sk(SK)

    # You can using this API now ! Here are some Examples
    body = dict()
    body['AppId'] = 'Your_AppId'
    body['BusinessId'] = 'Your_BusinessId'
    body['RoomId'] = 'Your_RoomId'
    body['TaskId'] = 'Your_TaskId'

    body = json.dumps(body)
    resp = rtc_service.stop_record(body)
    print(resp)




# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo


class RtcService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(RtcService, "_instance"):
            with RtcService._instance_lock:
                if not hasattr(RtcService, "_instance"):
                    RtcService._instance = object.__new__(cls)
        return RtcService._instance

    def __init__(self):
        self.service_info = RtcService.get_service_info()
        self.api_info = RtcService.get_api_info()
        super(RtcService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("rtc.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'rtc', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "StartRecord": ApiInfo("POST", "/", {"Action": "StartRecord", "Version": "2022-06-01"}, {}, {}),
            "StopRecord": ApiInfo("POST", "/", {"Action": "StopRecord", "Version": "2022-06-01"}, {}, {}),
            "GetRecordTask": ApiInfo("GET", "/", {"Action": "GetRecordTask", "Version": "2022-06-01"}, {}, {}),
        }
        return api_info

    def start_record(self, body):
        res = self.json("StartRecord", {}, body)
        if res == '':
            raise Exception("StartRecord: empty response")
        res_json = json.loads(res)
        return res_json

    def stop_record(self, body):
        res = self.json("StopRecord", {}, body)
        if res == '':
            raise Exception("StopRecord: empty response")
        res_json = json.loads(res)
        return res_json

    def get_record_task(self, params):
        res = self.get("GetRecordTask", params)
        if res == '':
            raise Exception("GetRecordTask: empty response")
        res_json = json.loads(res)
        return res_json



# coding:utf-8
from __future__ import print_function

import json

from volcengine.sms.SmsService import SmsService
from volcengine.const.Const import *

if __name__ == '__main__':
    sms_service = SmsService()
    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_host('host')

    body = {
        "SmsAccount": "smsAccount",
        "Sign": "sign",
        "TemplateID": "ST_xxx",
        "TemplateParam": {"code": "1234"},
        "PhoneNumbers": "188xxxxxxxx",
        "Tag": "tag",
    }

    body = json.dumps(body)
    resp = sms_service.send_sms(body)
    print(resp)

    body = {
        "SmsAccount": "smsAccount",
        "Sign": "sign",
        "TemplateID": "ST_xxx",
        "PhoneNumber": "188xxxxxxxx",
        "CodeType": 6,
        "TryCount": 3,
        "ExpireTime": 240,
        "Scene": "Test"
    }
    body = json.dumps(body)
    resp = sms_service.send_sms_verify_code(body)
    print(resp)

    body = {
        "SmsAccount": "smsAccount",
        "PhoneNumber": "188xxxxxxxx",
        "Scene": "Test",
        "Code": "123456"
    }
    body = json.dumps(body)
    resp = sms_service.check_sms_verify_code(body)
    print(resp)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import re
from typing import List, Dict

from volcengine.tls.const import *


def pascal_to_snake(pascal: str) -> str:
    return re.sub(r"(?P<key>[A-Z])", r"_\g<key>", pascal).lower().strip('_')


def snake_to_pascal(snake: str) -> str:
    return ''.join(word.title() for word in snake.split('_'))


class TLSData:
    @classmethod
    def set_attributes(cls, data: dict):
        if data is None or len(data) == 0:
            return None

        tls_data_dict = {}

        for key in data.keys():
            tls_data_dict[pascal_to_snake(key)] = data[key]

        tls_data = cls()

        for key in tls_data.__dict__.keys():
            tls_data.__dict__[key] = None

        tls_data.__dict__.update(tls_data_dict)

        return tls_data

    def json(self):
        json_data = {}

        for key in self.__dict__.keys():
            if self.__dict__[key] is not None:
                json_data[snake_to_pascal(key)] = self.__dict__[key]

        return json_data


class ProjectInfo(TLSData):
    def __init__(self, project_name: str = None, project_id: str = None, description: str = None,
                 create_time: str = None, inner_net_domain: str = None, topic_count: int = None):
        self.project_name = project_name
        self.project_id = project_id
        self.description = description
        self.create_time = create_time
        self.inner_net_domain = inner_net_domain
        self.topic_count = topic_count


class TopicInfo(TLSData):
    def __init__(self, topic_name: str = None, topic_id: str = None, project_id: str = None, ttl: int = None,
                 create_time: str = None, modify_time: str = None, shard_count: int = None, description: str = None):
        self.topic_name = topic_name
        self.topic_id = topic_id
        self.project_id = project_id
        self.ttl = ttl
        self.create_time = create_time
        self.modify_time = modify_time
        self.shard_count = shard_count
        self.description = description


class FullTextInfo(TLSData):
    def __init__(self, case_sensitive: bool, delimiter: str, include_chinese: bool = False):
        self.case_sensitive = case_sensitive
        self.delimiter = delimiter
        self.include_chinese = include_chinese

    @classmethod
    def set_attributes(cls, data: dict):
        case_sensitive = data.get(CASE_SENSITIVE)
        delimiter = data.get(DELIMITER)
        include_chinese = data.get(INCLUDE_CHINESE)

        return cls(case_sensitive, delimiter, include_chinese)


class ValueInfo(TLSData):
    def __init__(self, value_type: str, delimiter: str = None, case_sensitive: bool = False,
                 include_chinese: bool = False, sql_flag: bool = False):
        self.value_type = value_type
        self.delimiter = delimiter
        self.case_sensitive = case_sensitive
        self.include_chinese = include_chinese
        self.sql_flag = sql_flag

    @classmethod
    def set_attributes(cls, data: dict):
        value_type = data.get(VALUE_TYPE)
        delimiter = data.get(DELIMITER)
        case_sensitive = data.get(CASE_SENSITIVE)
        include_chinese = data.get(INCLUDE_CHINESE)
        sql_flag = data.get(SQL_FLAG)

        return cls(value_type, delimiter, case_sensitive, include_chinese, sql_flag)


class KeyValueInfo(TLSData):
    def __init__(self, key: str, value: ValueInfo):
        self.key = key
        self.value = value

    def json(self):
        return {KEY: self.key, VALUE: self.value.json()}


class AnalysisResult(TLSData):
    def __init__(self, analysis_schema: List[str] = None, analysis_type: dict = None, analysis_data: List[dict] = None):
        self.analysis_schema = analysis_schema
        self.analysis_type = analysis_type
        self.analysis_data = analysis_data

    @classmethod
    def set_attributes(cls, data: dict):
        analysis_schema = data.get(SCHEMA)
        analysis_type = data.get(TYPE)
        analysis_data = data.get(DATA)

        return cls(analysis_schema, analysis_type, analysis_data)


class SearchResult(TLSData):
    def __init__(self, result_status: str = None, hit_count: int = None, list_over: bool = None, analysis: bool = None,
                 count: int = None, limit: int = None, context: str = None, logs: List[dict] = None,
                 analysis_result: AnalysisResult = None):
        self.result_status = result_status
        self.hit_count = hit_count
        self.list_over = list_over
        self.analysis = analysis
        self.count = count
        self.limit = limit
        self.context = context
        self.logs = logs
        self.analysis_result = analysis_result

    @classmethod
    def set_attributes(cls, data: dict):
        search_result = super(SearchResult, cls).set_attributes(data)

        if ANALYSIS_RESULT in data:
            search_result.analysis_result = AnalysisResult.set_attributes(data=data[ANALYSIS_RESULT])

        return search_result


class QueryResp(TLSData):
    def __init__(self, topic_id: str = None, shard_id: int = None, inclusive_begin_key: str = None,
                 exclusive_end_key: str = None, status: str = None, modify_time: str = None):
        self.topic_id = topic_id
        self.shard_id = shard_id
        self.inclusive_begin_key = inclusive_begin_key
        self.exclusive_end_key = exclusive_end_key
        self.status = status
        self.modify_time = modify_time


class HistogramInfo(TLSData):
    def __init__(self, time: int = None, count: int = None):
        self.time = time
        self.count = count


class TaskInfo(TLSData):
    def __init__(self, task_id: str = None, task_name: str = None, topic_id: str = None, query: str = None,
                 start_time: str = None, end_time: str = None, data_format: str = None, task_status: str = None,
                 compression: str = None, create_time: str = None, log_size: int = None, log_count: int = None):
        self.task_id = task_id
        self.task_name = task_name
        self.topic_id = topic_id
        self.query = query
        self.start_time = start_time
        self.end_time = end_time
        self.data_format = data_format
        self.task_status = task_status
        self.compression = compression
        self.create_time = create_time
        self.log_size = log_size
        self.log_count = log_count


class HostInfo(TLSData):
    def __init__(self, ip: str = None, log_collector_version: str = None, heartbeat_status: int = None):
        self.ip = ip
        self.log_collector_version = log_collector_version
        self.heartbeat_status = heartbeat_status


class HostGroupInfo(TLSData):
    def __init__(self, host_group_id: str = None, host_group_name: str = None, host_group_type: str = None,
                 host_identifier: str = None, host_count: int = None, normal_heartbeat_status_count: int = None,
                 abnormal_heartbeat_status_count: int = None, rule_count: int = None,
                 create_time: str = None, modify_time: str = None, auto_update: bool = False,
                 update_start_time: str = None, update_end_time: str = None, agent_latest_version: str = None):
        self.host_group_id = host_group_id
        self.host_group_name = host_group_name
        self.host_group_type = host_group_type
        self.host_identifier = host_identifier
        self.host_count = host_count
        self.normal_heartbeat_status_count = normal_heartbeat_status_count
        self.abnormal_heartbeat_status_count = abnormal_heartbeat_status_count
        self.rule_count = rule_count
        self.create_time = create_time
        self.modify_time = modify_time
        self.auto_update = auto_update
        self.update_start_time = update_start_time
        self.update_end_time = update_end_time
        self.agent_latest_version = agent_latest_version


class FilterKeyRegex(TLSData):
    def __init__(self, key: str, regex: str):
        self.key = key
        self.regex = regex

    @classmethod
    def set_attributes(cls, data: dict):
        key = data.get(KEY)
        regex = data.get(REGEX)

        return cls(key, regex)


class LogTemplate(TLSData):
    def __init__(self, log_type: str, log_format: str):
        self.log_type = log_type
        self.log_format = log_format

    def json(self):
        return {TYPE: self.log_type, FORMAT: self.log_format}


class ExtractRule(TLSData):
    def __init__(self, delimiter: str = None, begin_regex: str = None, log_regex: str = None, keys: List[str] = None,
                 time_key: str = None, time_format: str = None, filter_key_regex: List[FilterKeyRegex] = None,
                 un_match_up_load_switch: bool = None, un_match_log_key: str = None, log_template: LogTemplate = None):
        assert (time_key is None and time_format is None) or (time_key is not None and time_format is not None)
        assert (un_match_up_load_switch is None and un_match_log_key is None) or \
               (un_match_up_load_switch is not None and un_match_log_key is not None)

        self.delimiter = delimiter
        self.begin_regex = begin_regex
        self.log_regex = log_regex
        self.keys = keys
        self.time_key = time_key
        self.time_format = time_format
        self.filter_key_regex = filter_key_regex
        self.un_match_up_load_switch = un_match_up_load_switch
        self.un_match_log_key = un_match_log_key
        self.log_template = log_template

    @classmethod
    def set_attributes(cls, data: dict):
        extract_rule = super(ExtractRule, cls).set_attributes(data)

        if FILTER_KEY_REGEX in data:
            extract_rule.filter_key_regex = []
            for one_filter_key_regex in data[FILTER_KEY_REGEX]:
                extract_rule.filter_key_regex.append(FilterKeyRegex.set_attributes(data=one_filter_key_regex))
        if LOG_TEMPLATE in data:
            extract_rule.log_template = LogTemplate(log_type=data[LOG_TEMPLATE].get(TYPE),
                                                    log_format=data[LOG_TEMPLATE].get(FORMAT))

        return extract_rule

    def json(self):
        json_data = super(ExtractRule, self).json()

        if self.filter_key_regex is not None:
            json_data[FILTER_KEY_REGEX] = []
            for regex in self.filter_key_regex:
                json_data[FILTER_KEY_REGEX].append(regex.json())
        if self.log_template is not None:
            json_data[LOG_TEMPLATE] = self.log_template.json()

        return json_data


class ExcludePath(TLSData):
    def __init__(self, path_type: str, value: str):
        assert path_type == "File" or path_type == "Path"

        self.path_type = path_type
        self.value = value

    @classmethod
    def set_attributes(cls, data: dict):
        path_type = data.get(TYPE)
        value = data.get(VALUE)

        return cls(path_type, value)

    def json(self):
        return {TYPE: self.path_type, VALUE: self.value}


class ParsePathRule(TLSData):
    def __init__(self, path_sample: str, regex: str, keys: List[str]):
        self.path_sample = path_sample
        self.regex = regex
        self.keys = keys

    @classmethod
    def set_attributes(cls, data: dict):
        path_sample = data.get(PATH_SAMPLE)
        regex = data.get(REGEX)
        keys = data.get(KEYS)

        return cls(path_sample, regex, keys)


class ShardHashKey(TLSData):
    def __init__(self, hash_key: str):
        self.hash_key = hash_key


class UserDefineRule(TLSData):
    def __init__(self, parse_path_rule: ParsePathRule = None, shard_hash_key: ShardHashKey = None,
                 enable_raw_log: bool = False, fields: dict = None):
        self.parse_path_rule = parse_path_rule
        self.shard_hash_key = shard_hash_key
        self.enable_raw_log = enable_raw_log
        self.fields = fields

    @classmethod
    def set_attributes(cls, data: dict):
        user_define_rule = super(UserDefineRule, cls).set_attributes(data)

        if SHARD_HASH_KEY in data:
            user_define_rule.shard_hash_key = ShardHashKey(hash_key=data[SHARD_HASH_KEY].get(HASH_KEY))
        if PARSE_PATH_RULE in data:
            user_define_rule.parse_path_rule = ParsePathRule.set_attributes(data[PARSE_PATH_RULE])

        return user_define_rule

    def json(self):
        json_data = super(UserDefineRule, self).json()

        if self.shard_hash_key is not None:
            json_data[SHARD_HASH_KEY] = self.shard_hash_key.json()
        if self.parse_path_rule is not None:
            json_data[PARSE_PATH_RULE] = self.parse_path_rule.json()

        return json_data


class KubernetesRule(TLSData):
    def __init__(self, namespace_name_regex: str = None, workload_type: str = None, workload_name_regex: str = None,
                 include_pod_label_regex: Dict[str, str] = None, exclude_pod_label_regex: Dict[str, str] = None,
                 pod_name_regex: str = None, label_tag: Dict[str, str] = None):
        self.namespace_name_regex = namespace_name_regex
        self.workload_type = workload_type
        self.workload_name_regex = workload_name_regex
        self.include_pod_label_regex = include_pod_label_regex
        self.exclude_pod_label_regex = exclude_pod_label_regex
        self.pod_name_regex = pod_name_regex
        self.label_tag = label_tag


class ContainerRule(TLSData):
    def __init__(self, stream: str = None, container_name_regex: str = None,
                 include_container_label_regex: Dict[str, str] = None,
                 exclude_container_label_regex: Dict[str, str] = None,
                 include_container_env_regex: Dict[str, str] = None,
                 exclude_container_env_regex: Dict[str, str] = None,
                 env_tag: Dict[str, str] = None, kubernetes_rule: KubernetesRule = None):
        self.stream = stream
        self.container_name_regex = container_name_regex
        self.include_container_label_regex = include_container_label_regex
        self.exclude_container_label_regex = exclude_container_label_regex
        self.include_container_env_regex = include_container_env_regex
        self.exclude_container_env_regex = exclude_container_env_regex
        self.env_tag = env_tag
        self.kubernetes_rule = kubernetes_rule

    @classmethod
    def set_attributes(cls, data: dict):
        container_rule = super(ContainerRule, cls).set_attributes(data)

        if KUBERNETES_RULE in data:
            container_rule.kubernetes_rule = KubernetesRule.set_attributes(data=data[KUBERNETES_RULE])

        return container_rule

    def json(self):
        json_data = super(ContainerRule, self).json()

        if self.kubernetes_rule is not None:
            json_data[KUBERNETES_RULE] = self.kubernetes_rule.json()

        return json_data


class RuleInfo(TLSData):
    def __init__(self, topic_id: str = None, topic_name: str = None, rule_id: str = None, rule_name: str = None,
                 paths: List[str] = None, log_type: str = None, extract_rule: ExtractRule = None,
                 exclude_paths: List[ExcludePath] = None, log_sample: str = None,
                 user_define_rule: UserDefineRule = None, create_time: str = None, modify_time: str = None,
                 input_type: int = None, container_rule: ContainerRule = None):
        self.topic_id = topic_id
        self.topic_name = topic_name
        self.rule_id = rule_id
        self.rule_name = rule_name
        self.paths = paths
        self.log_type = log_type
        self.extract_rule = extract_rule
        self.exclude_paths = exclude_paths
        self.log_sample = log_sample
        self.user_define_rule = user_define_rule
        self.create_time = create_time
        self.modify_time = modify_time
        self.input_type = input_type
        self.container_rule = container_rule

    @classmethod
    def set_attributes(cls, data: dict):
        rule_info = super(RuleInfo, cls).set_attributes(data)

        if EXTRACT_RULE in data:
            rule_info.extract_rule = ExtractRule.set_attributes(data=data[EXTRACT_RULE])
        if EXCLUDE_PATHS in data:
            rule_info.exclude_paths = []
            for exclude_path in data[EXCLUDE_PATHS]:
                rule_info.exclude_paths.append(ExcludePath.set_attributes(data=exclude_path))
        if USER_DEFINE_RULE in data:
            rule_info.user_define_rule = UserDefineRule.set_attributes(data=data[USER_DEFINE_RULE])
        if CONTAINER_RULE in data:
            rule_info.container_rule = ContainerRule.set_attributes(data=data[CONTAINER_RULE])

        return rule_info


class HostGroupHostsRulesInfo(TLSData):
    def __init__(self, host_group_info: HostGroupInfo, host_infos: List[HostInfo], rule_infos: List[RuleInfo]):
        self.host_group_info = host_group_info
        self.host_infos = host_infos
        self.rule_infos = rule_infos


class Receiver(TLSData):
    def __init__(self, receiver_type: str, receiver_names: List[str], receiver_channels: List[str],
                 start_time: str, end_time: str, webhook: str = None):
        self.receiver_type = receiver_type
        self.receiver_names = receiver_names
        self.receiver_channels = receiver_channels
        self.start_time = start_time
        self.end_time = end_time
        self.webhook = webhook

    @classmethod
    def set_attributes(cls, data: dict):
        receiver_type = data.get(RECEIVER_TYPE)
        receiver_names = data.get(RECEIVER_NAMES)
        receiver_channels = data.get(RECEIVER_CHANNELS)
        start_time = data.get(START_TIME)
        end_time = data.get(END_TIME)
        webhook = data.get(WEBHOOK)

        return cls(receiver_type, receiver_names, receiver_channels, start_time, end_time, webhook)


class QueryRequest(TLSData):
    def __init__(self, topic_id: str, query: str, number: int,
                 start_time_offset: int, end_time_offset: int, topic_name: str = None):
        self.topic_id = topic_id
        self.query = query
        self.number = number
        self.start_time_offset = start_time_offset
        self.end_time_offset = end_time_offset
        self.topic_name = topic_name

    @classmethod
    def set_attributes(cls, data: dict):
        topic_id = data.get(TOPIC_ID)
        topic_name = data.get(TOPIC_NAME)
        query = data.get(QUERY)
        number = data.get(NUMBER)
        start_time_offset = data.get(START_TIME_OFFSET)
        end_time_offset = data.get(END_TIME_OFFSET)

        return cls(topic_id, topic_name, query, number, start_time_offset, end_time_offset)


class RequestCycle(TLSData):
    def __init__(self, cycle_type: str, time: int):
        self.cycle_type = cycle_type
        self.time = time

    @classmethod
    def set_attributes(cls, data: dict):
        cycle_type = data.get(TYPE)
        time = data.get(TIME)

        return cls(cycle_type, time)

    def json(self):
        return {TYPE: self.cycle_type, TIME: self.time}


class AlarmNotifyGroupInfo(TLSData):
    def __init__(self, alarm_notify_group_name: str = None, alarm_notify_group_id: str = None,
                 notify_type: List[str] = None, receivers: List[Receiver] = None,
                 create_time: str = None, modify_time: str = None):
        self.alarm_notify_group_name = alarm_notify_group_name
        self.alarm_notify_group_id = alarm_notify_group_id
        self.notify_type = notify_type
        self.receivers = receivers
        self.create_time = create_time
        self.modify_time = modify_time

    @classmethod
    def set_attributes(cls, data: dict):
        alarm_notify_group_info = super(AlarmNotifyGroupInfo, cls).set_attributes(data)

        if RECEIVERS in data:
            alarm_notify_group_info.receivers = []
            for receiver in data[RECEIVERS]:
                alarm_notify_group_info.receivers.append(Receiver.set_attributes(data=receiver))

        return alarm_notify_group_info


class AlarmInfo(TLSData):
    def __init__(self, alarm_name: str = None, alarm_id: str = None, project_id: str = None, status: bool = None,
                 query_request: List[QueryRequest] = None, request_cycle: RequestCycle = None, condition: str = None,
                 trigger_period: int = None, alarm_period: int = None,
                 alarm_notify_group: List[AlarmNotifyGroupInfo] = None, user_define_msg: str = None,
                 create_time: str = None, modify_time: str = None):
        self.alarm_name = alarm_name
        self.alarm_id = alarm_id
        self.project_id = project_id
        self.status = status
        self.query_request = query_request
        self.request_cycle = request_cycle
        self.condition = condition
        self.trigger_period = trigger_period
        self.alarm_period = alarm_period
        self.alarm_notify_group = alarm_notify_group
        self.user_define_msg = user_define_msg
        self.create_time = create_time
        self.modify_time = modify_time

    @classmethod
    def set_attributes(cls, data: dict):
        alarm_info = super(AlarmInfo, cls).set_attributes(data)

        if REQUEST_CYCLE in data:
            alarm_info.request_cycle = RequestCycle.set_attributes(data=data[REQUEST_CYCLE])
        if QUERY_REQUEST in data:
            alarm_info.query_request = []
            for one_query_request in data[QUERY_REQUEST]:
                alarm_info.query_request.append(QueryRequest.set_attributes(data=one_query_request))
        if ALARM_NOTIFY_GROUP in data:
            alarm_info.alarm_notify_group = []
            for alarm_notify_group in data[ALARM_NOTIFY_GROUP]:
                alarm_info.alarm_notify_group.append(AlarmNotifyGroupInfo.set_attributes(data=alarm_notify_group))

        return alarm_info



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_upload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvod/business/vod_upload.proto\x12\x1eVolcengine.Vod.Models.Business\x1a\x1dvod/business/vod_common.proto\"\xb6\x02\n\x12VodUrlUploadURLSet\x12\x11\n\tSourceUrl\x18\x01 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x02 \x01(\t\x12\x0b\n\x03Md5\x18\x03 \x01(\t\x12\x12\n\nTemplateId\x18\x04 \x01(\t\x12\r\n\x05Title\x18\x05 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x06 \x01(\t\x12\x0c\n\x04Tags\x18\x07 \x01(\t\x12\x10\n\x08\x43\x61tegory\x18\x08 \x01(\t\x12\x10\n\x08\x46ileName\x18\t \x01(\t\x12\x18\n\x10\x43lassificationId\x18\n \x01(\x03\x12\x14\n\x0cStorageClass\x18\x0b \x01(\x05\x12\x15\n\rFileExtension\x18\x0c \x01(\t\x12\x1e\n\x16UrlEncryptionAlgorithm\x18\r \x01(\t\x12\x19\n\x11\x45nableLowPriority\x18\x0e \x01(\x08\"M\n\x12VodUrlResponseData\x12\x37\n\x04\x44\x61ta\x18\x01 \x03(\x0b\x32).Volcengine.Vod.Models.Business.ValuePair\"-\n\tValuePair\x12\r\n\x05JobId\x18\x01 \x01(\t\x12\x11\n\tSourceUrl\x18\x02 \x01(\t\"R\n\x0cVodQueryData\x12\x42\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodQueryUploadResult\"p\n\x14VodQueryUploadResult\x12@\n\rMediaInfoList\x18\x01 \x03(\x0b\x32).Volcengine.Vod.Models.Business.VodURLSet\x12\x16\n\x0eNotExistJobIds\x18\x02 \x03(\t\"^\n\rVodCommitData\x12M\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32?.Volcengine.Vod.Models.Business.VodCommitUploadInfoResponseData\"\xa7\x01\n\x1fVodCommitUploadInfoResponseData\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x41\n\nSourceInfo\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12\x11\n\tPosterUri\x18\x03 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x04 \x01(\t\x12\x0b\n\x03Mid\x18\x05 \x01(\t\"\xc5\x01\n\tVodURLSet\x12\x11\n\tRequestId\x18\x01 \x01(\t\x12\r\n\x05JobId\x18\x02 \x01(\t\x12\x11\n\tSourceUrl\x18\x03 \x01(\t\x12\r\n\x05State\x18\x04 \x01(\t\x12\x0b\n\x03Vid\x18\x05 \x01(\t\x12\x11\n\tSpaceName\x18\x06 \x01(\t\x12\x11\n\tAccountId\x18\x07 \x01(\t\x12\x41\n\nSourceInfo\x18\x08 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\"`\n\x18VodApplyUploadInfoResult\x12\x44\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodApplyUploadInfoData\"a\n\x16VodApplyUploadInfoData\x12G\n\rUploadAddress\x18\x01 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodUploadAddress\"\xc2\x01\n\x10VodUploadAddress\x12@\n\nStoreInfos\x18\x01 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodStoreInfo\x12\x13\n\x0bUploadHosts\x18\x02 \x03(\t\x12\x43\n\x0cUploadHeader\x18\x03 \x03(\x0b\x32-.Volcengine.Vod.Models.Business.VodHeaderPair\x12\x12\n\nSessionKey\x18\x04 \x01(\t\".\n\x0cVodStoreInfo\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x0c\n\x04\x41uth\x18\x02 \x01(\t\"+\n\rVodHeaderPair\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"b\n\x19VodCommitUploadInfoResult\x12\x45\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodCommitUploadInfoData\"\x89\x01\n\x17VodCommitUploadInfoData\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x11\n\tPosterUri\x18\x02 \x01(\t\x12\x41\n\nSourceInfo\x18\x03 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12\x0b\n\x03Mid\x18\x04 \x01(\t\"\xc8\x02\n\x16VodUploadFunctionInput\x12\x14\n\x0cSnapshotTime\x18\x01 \x01(\x01\x12\r\n\x05Title\x18\x02 \x01(\t\x12\x0c\n\x04Tags\x18\x03 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x04 \x01(\t\x12\x10\n\x08\x43\x61tegory\x18\x05 \x01(\t\x12\x12\n\nRecordType\x18\x06 \x01(\x05\x12\x0e\n\x06\x46ormat\x18\x07 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x08 \x01(\x05\x12\x12\n\nTemplateId\x18\t \x01(\t\x12\x0b\n\x03Vid\x18\n \x01(\t\x12\x0b\n\x03\x46id\x18\x0b \x01(\t\x12\x10\n\x08Language\x18\x0c \x01(\t\x12\x10\n\x08StoreUri\x18\r \x01(\t\x12\x0e\n\x06Source\x18\x0e \x01(\t\x12\x0b\n\x03Tag\x18\x0f \x01(\t\x12\x13\n\x0b\x41utoPublish\x18\x10 \x01(\x08\x12\x12\n\nActionType\x18\x11 \x01(\t\"h\n\x11VodUploadFunction\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x45\n\x05Input\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodUploadFunctionInput\"\xaf\x01\n\x15\x43ommitUploadInfoParam\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x02 \x01(\t\x12\x12\n\nSessionKey\x18\x03 \x01(\t\x12\x44\n\tFunctions\x18\x04 \x03(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodUploadFunction\x12\x13\n\x0bGetMetaMode\x18\x05 \x01(\t\"|\n\x15\x43ommitRequestBodyJson\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x12\n\nSessionKey\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x11\n\tFunctions\x18\x04 \x01(\t\x12\x13\n\x0bGetMetaMode\x18\x05 \x01(\t\"\xec\x01\n\x14\x41pplyUploadInfoParam\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x10\n\x08\x46ileType\x18\x02 \x01(\t\x12\x12\n\nSessionKey\x18\x03 \x01(\t\x12\x10\n\x08\x46ileSize\x18\x04 \x01(\x01\x12\x11\n\tMediaType\x18\x05 \x01(\t\x12\x0f\n\x07TosKeys\x18\x06 \x01(\t\x12\x15\n\rFileExtension\x18\x07 \x01(\t\x12\x12\n\nFilePrefix\x18\x08 \x01(\t\x12\x17\n\x0f\x46lushUploadMode\x18\t \x01(\x05\x12\x0b\n\x03Md5\x18\n \x01(\t\x12\x14\n\x0cStorageClass\x18\x0b \x01(\x05\"\x96\x01\n\x0e\x43ommitResponse\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0b\n\x03Mid\x18\x02 \x01(\t\x12\x41\n\nSourceInfo\x18\x03 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12\x11\n\tPosterUri\x18\x04 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x05 \x01(\t\")\n\x13VodUploadOptionInfo\x12\x12\n\nTemplateId\x18\x01 \x01(\t\"\x98\x02\n\x15VodUploadCallbackData\x12\x0c\n\x04\x43ode\x18\x01 \x01(\t\x12\x0f\n\x07Message\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x0b\n\x03Vid\x18\x04 \x01(\t\x12\x0b\n\x03Mid\x18\x05 \x01(\t\x12\x11\n\tSpaceName\x18\x06 \x01(\t\x12\x41\n\nSourceInfo\x18\x07 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12\x11\n\tPosterUri\x18\x08 \x01(\t\x12G\n\nOptionInfo\x18\t \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodUploadOptionInfo\"\xa1\x01\n\x10\x43\x61llbackResponse\x12\x11\n\tRequestId\x18\x01 \x01(\t\x12\x0f\n\x07Version\x18\x02 \x01(\t\x12\x11\n\tEventTime\x18\x03 \x01(\t\x12\x11\n\tEventType\x18\x04 \x01(\t\x12\x43\n\x04\x44\x61ta\x18\x05 \x01(\x0b\x32\x35.Volcengine.Vod.Models.Business.VodUploadCallbackData\"+\n\tStoreInfo\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x0c\n\x04\x41uth\x18\x02 \x01(\t\"(\n\nHeaderPair\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"\xb9\x01\n\rUploadAddress\x12=\n\nStoreInfos\x18\x01 \x03(\x0b\x32).Volcengine.Vod.Models.Business.StoreInfo\x12\x13\n\x0bUploadHosts\x18\x02 \x03(\t\x12@\n\x0cUploadHeader\x18\x03 \x03(\x0b\x32*.Volcengine.Vod.Models.Business.HeaderPair\x12\x12\n\nSessionKey\x18\x04 \x01(\t\"\xae\x01\n\x11\x46lushUploadResult\x12\x13\n\x0b\x46lushUpload\x18\x01 \x01(\x08\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\x0b\n\x03Mid\x18\x03 \x01(\t\x12\x41\n\nSourceInfo\x18\x04 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12\x11\n\tPosterUri\x18\x05 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x06 \x01(\t\"\xb5\x01\n\rApplyResponse\x12\x44\n\rUploadAddress\x18\x01 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.UploadAddress\x12L\n\x11\x46lushUploadResult\x18\x02 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.FlushUploadResult\x12\x10\n\x08SDKParam\x18\x03 \x01(\t*:\n\x10StorageClassType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x0c\n\x08Standard\x10\x01\x12\x0b\n\x07\x41rchive\x10\x02\x42\xcd\x01\n)com.volcengine.service.vod.model.businessB\tVodUploadP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_STORAGECLASSTYPE = DESCRIPTOR.enum_types_by_name['StorageClassType']
StorageClassType = enum_type_wrapper.EnumTypeWrapper(_STORAGECLASSTYPE)
Default = 0
Standard = 1
Archive = 2


_VODURLUPLOADURLSET = DESCRIPTOR.message_types_by_name['VodUrlUploadURLSet']
_VODURLRESPONSEDATA = DESCRIPTOR.message_types_by_name['VodUrlResponseData']
_VALUEPAIR = DESCRIPTOR.message_types_by_name['ValuePair']
_VODQUERYDATA = DESCRIPTOR.message_types_by_name['VodQueryData']
_VODQUERYUPLOADRESULT = DESCRIPTOR.message_types_by_name['VodQueryUploadResult']
_VODCOMMITDATA = DESCRIPTOR.message_types_by_name['VodCommitData']
_VODCOMMITUPLOADINFORESPONSEDATA = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResponseData']
_VODURLSET = DESCRIPTOR.message_types_by_name['VodURLSet']
_VODAPPLYUPLOADINFORESULT = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoResult']
_VODAPPLYUPLOADINFODATA = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoData']
_VODUPLOADADDRESS = DESCRIPTOR.message_types_by_name['VodUploadAddress']
_VODSTOREINFO = DESCRIPTOR.message_types_by_name['VodStoreInfo']
_VODHEADERPAIR = DESCRIPTOR.message_types_by_name['VodHeaderPair']
_VODCOMMITUPLOADINFORESULT = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResult']
_VODCOMMITUPLOADINFODATA = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoData']
_VODUPLOADFUNCTIONINPUT = DESCRIPTOR.message_types_by_name['VodUploadFunctionInput']
_VODUPLOADFUNCTION = DESCRIPTOR.message_types_by_name['VodUploadFunction']
_COMMITUPLOADINFOPARAM = DESCRIPTOR.message_types_by_name['CommitUploadInfoParam']
_COMMITREQUESTBODYJSON = DESCRIPTOR.message_types_by_name['CommitRequestBodyJson']
_APPLYUPLOADINFOPARAM = DESCRIPTOR.message_types_by_name['ApplyUploadInfoParam']
_COMMITRESPONSE = DESCRIPTOR.message_types_by_name['CommitResponse']
_VODUPLOADOPTIONINFO = DESCRIPTOR.message_types_by_name['VodUploadOptionInfo']
_VODUPLOADCALLBACKDATA = DESCRIPTOR.message_types_by_name['VodUploadCallbackData']
_CALLBACKRESPONSE = DESCRIPTOR.message_types_by_name['CallbackResponse']
_STOREINFO = DESCRIPTOR.message_types_by_name['StoreInfo']
_HEADERPAIR = DESCRIPTOR.message_types_by_name['HeaderPair']
_UPLOADADDRESS = DESCRIPTOR.message_types_by_name['UploadAddress']
_FLUSHUPLOADRESULT = DESCRIPTOR.message_types_by_name['FlushUploadResult']
_APPLYRESPONSE = DESCRIPTOR.message_types_by_name['ApplyResponse']
VodUrlUploadURLSet = _reflection.GeneratedProtocolMessageType('VodUrlUploadURLSet', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADURLSET,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUrlUploadURLSet)
  })
_sym_db.RegisterMessage(VodUrlUploadURLSet)

VodUrlResponseData = _reflection.GeneratedProtocolMessageType('VodUrlResponseData', (_message.Message,), {
  'DESCRIPTOR' : _VODURLRESPONSEDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUrlResponseData)
  })
_sym_db.RegisterMessage(VodUrlResponseData)

ValuePair = _reflection.GeneratedProtocolMessageType('ValuePair', (_message.Message,), {
  'DESCRIPTOR' : _VALUEPAIR,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.ValuePair)
  })
_sym_db.RegisterMessage(ValuePair)

VodQueryData = _reflection.GeneratedProtocolMessageType('VodQueryData', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodQueryData)
  })
_sym_db.RegisterMessage(VodQueryData)

VodQueryUploadResult = _reflection.GeneratedProtocolMessageType('VodQueryUploadResult', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADRESULT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodQueryUploadResult)
  })
_sym_db.RegisterMessage(VodQueryUploadResult)

VodCommitData = _reflection.GeneratedProtocolMessageType('VodCommitData', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitData)
  })
_sym_db.RegisterMessage(VodCommitData)

VodCommitUploadInfoResponseData = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResponseData', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESPONSEDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitUploadInfoResponseData)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResponseData)

VodURLSet = _reflection.GeneratedProtocolMessageType('VodURLSet', (_message.Message,), {
  'DESCRIPTOR' : _VODURLSET,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodURLSet)
  })
_sym_db.RegisterMessage(VodURLSet)

VodApplyUploadInfoResult = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFORESULT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodApplyUploadInfoResult)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoResult)

VodApplyUploadInfoData = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoData', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFODATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodApplyUploadInfoData)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoData)

VodUploadAddress = _reflection.GeneratedProtocolMessageType('VodUploadAddress', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADADDRESS,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUploadAddress)
  })
_sym_db.RegisterMessage(VodUploadAddress)

VodStoreInfo = _reflection.GeneratedProtocolMessageType('VodStoreInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODSTOREINFO,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodStoreInfo)
  })
_sym_db.RegisterMessage(VodStoreInfo)

VodHeaderPair = _reflection.GeneratedProtocolMessageType('VodHeaderPair', (_message.Message,), {
  'DESCRIPTOR' : _VODHEADERPAIR,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodHeaderPair)
  })
_sym_db.RegisterMessage(VodHeaderPair)

VodCommitUploadInfoResult = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESULT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitUploadInfoResult)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResult)

VodCommitUploadInfoData = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoData', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFODATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitUploadInfoData)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoData)

VodUploadFunctionInput = _reflection.GeneratedProtocolMessageType('VodUploadFunctionInput', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADFUNCTIONINPUT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUploadFunctionInput)
  })
_sym_db.RegisterMessage(VodUploadFunctionInput)

VodUploadFunction = _reflection.GeneratedProtocolMessageType('VodUploadFunction', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADFUNCTION,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUploadFunction)
  })
_sym_db.RegisterMessage(VodUploadFunction)

CommitUploadInfoParam = _reflection.GeneratedProtocolMessageType('CommitUploadInfoParam', (_message.Message,), {
  'DESCRIPTOR' : _COMMITUPLOADINFOPARAM,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CommitUploadInfoParam)
  })
_sym_db.RegisterMessage(CommitUploadInfoParam)

CommitRequestBodyJson = _reflection.GeneratedProtocolMessageType('CommitRequestBodyJson', (_message.Message,), {
  'DESCRIPTOR' : _COMMITREQUESTBODYJSON,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CommitRequestBodyJson)
  })
_sym_db.RegisterMessage(CommitRequestBodyJson)

ApplyUploadInfoParam = _reflection.GeneratedProtocolMessageType('ApplyUploadInfoParam', (_message.Message,), {
  'DESCRIPTOR' : _APPLYUPLOADINFOPARAM,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.ApplyUploadInfoParam)
  })
_sym_db.RegisterMessage(ApplyUploadInfoParam)

CommitResponse = _reflection.GeneratedProtocolMessageType('CommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMITRESPONSE,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CommitResponse)
  })
_sym_db.RegisterMessage(CommitResponse)

VodUploadOptionInfo = _reflection.GeneratedProtocolMessageType('VodUploadOptionInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADOPTIONINFO,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUploadOptionInfo)
  })
_sym_db.RegisterMessage(VodUploadOptionInfo)

VodUploadCallbackData = _reflection.GeneratedProtocolMessageType('VodUploadCallbackData', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADCALLBACKDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUploadCallbackData)
  })
_sym_db.RegisterMessage(VodUploadCallbackData)

CallbackResponse = _reflection.GeneratedProtocolMessageType('CallbackResponse', (_message.Message,), {
  'DESCRIPTOR' : _CALLBACKRESPONSE,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CallbackResponse)
  })
_sym_db.RegisterMessage(CallbackResponse)

StoreInfo = _reflection.GeneratedProtocolMessageType('StoreInfo', (_message.Message,), {
  'DESCRIPTOR' : _STOREINFO,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.StoreInfo)
  })
_sym_db.RegisterMessage(StoreInfo)

HeaderPair = _reflection.GeneratedProtocolMessageType('HeaderPair', (_message.Message,), {
  'DESCRIPTOR' : _HEADERPAIR,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.HeaderPair)
  })
_sym_db.RegisterMessage(HeaderPair)

UploadAddress = _reflection.GeneratedProtocolMessageType('UploadAddress', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADADDRESS,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.UploadAddress)
  })
_sym_db.RegisterMessage(UploadAddress)

FlushUploadResult = _reflection.GeneratedProtocolMessageType('FlushUploadResult', (_message.Message,), {
  'DESCRIPTOR' : _FLUSHUPLOADRESULT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.FlushUploadResult)
  })
_sym_db.RegisterMessage(FlushUploadResult)

ApplyResponse = _reflection.GeneratedProtocolMessageType('ApplyResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYRESPONSE,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.ApplyResponse)
  })
_sym_db.RegisterMessage(ApplyResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\tVodUploadP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _STORAGECLASSTYPE._serialized_start=4185
  _STORAGECLASSTYPE._serialized_end=4243
  _VODURLUPLOADURLSET._serialized_start=97
  _VODURLUPLOADURLSET._serialized_end=407
  _VODURLRESPONSEDATA._serialized_start=409
  _VODURLRESPONSEDATA._serialized_end=486
  _VALUEPAIR._serialized_start=488
  _VALUEPAIR._serialized_end=533
  _VODQUERYDATA._serialized_start=535
  _VODQUERYDATA._serialized_end=617
  _VODQUERYUPLOADRESULT._serialized_start=619
  _VODQUERYUPLOADRESULT._serialized_end=731
  _VODCOMMITDATA._serialized_start=733
  _VODCOMMITDATA._serialized_end=827
  _VODCOMMITUPLOADINFORESPONSEDATA._serialized_start=830
  _VODCOMMITUPLOADINFORESPONSEDATA._serialized_end=997
  _VODURLSET._serialized_start=1000
  _VODURLSET._serialized_end=1197
  _VODAPPLYUPLOADINFORESULT._serialized_start=1199
  _VODAPPLYUPLOADINFORESULT._serialized_end=1295
  _VODAPPLYUPLOADINFODATA._serialized_start=1297
  _VODAPPLYUPLOADINFODATA._serialized_end=1394
  _VODUPLOADADDRESS._serialized_start=1397
  _VODUPLOADADDRESS._serialized_end=1591
  _VODSTOREINFO._serialized_start=1593
  _VODSTOREINFO._serialized_end=1639
  _VODHEADERPAIR._serialized_start=1641
  _VODHEADERPAIR._serialized_end=1684
  _VODCOMMITUPLOADINFORESULT._serialized_start=1686
  _VODCOMMITUPLOADINFORESULT._serialized_end=1784
  _VODCOMMITUPLOADINFODATA._serialized_start=1787
  _VODCOMMITUPLOADINFODATA._serialized_end=1924
  _VODUPLOADFUNCTIONINPUT._serialized_start=1927
  _VODUPLOADFUNCTIONINPUT._serialized_end=2255
  _VODUPLOADFUNCTION._serialized_start=2257
  _VODUPLOADFUNCTION._serialized_end=2361
  _COMMITUPLOADINFOPARAM._serialized_start=2364
  _COMMITUPLOADINFOPARAM._serialized_end=2539
  _COMMITREQUESTBODYJSON._serialized_start=2541
  _COMMITREQUESTBODYJSON._serialized_end=2665
  _APPLYUPLOADINFOPARAM._serialized_start=2668
  _APPLYUPLOADINFOPARAM._serialized_end=2904
  _COMMITRESPONSE._serialized_start=2907
  _COMMITRESPONSE._serialized_end=3057
  _VODUPLOADOPTIONINFO._serialized_start=3059
  _VODUPLOADOPTIONINFO._serialized_end=3100
  _VODUPLOADCALLBACKDATA._serialized_start=3103
  _VODUPLOADCALLBACKDATA._serialized_end=3383
  _CALLBACKRESPONSE._serialized_start=3386
  _CALLBACKRESPONSE._serialized_end=3547
  _STOREINFO._serialized_start=3549
  _STOREINFO._serialized_end=3592
  _HEADERPAIR._serialized_start=3594
  _HEADERPAIR._serialized_end=3634
  _UPLOADADDRESS._serialized_start=3637
  _UPLOADADDRESS._serialized_end=3822
  _FLUSHUPLOADRESULT._serialized_start=3825
  _FLUSHUPLOADRESULT._serialized_end=3999
  _APPLYRESPONSE._serialized_start=4002
  _APPLYRESPONSE._serialized_end=4183
# @@protoc_insertion_point(module_scope)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

try:
    import lz4
except ImportError:
    lz4 = None
import json


from volcengine.tls.log_pb2 import LogGroupList
from volcengine.tls.data import *
from volcengine.tls.tls_exception import TLSException


class TLSRequest:
    def get_api_input(self):
        api_input = {}

        for key in self.__dict__.keys():
            if self.__dict__[key] is not None:
                api_input[snake_to_pascal(key)] = self.__dict__[key]

        return api_input


class CreateProjectRequest(TLSRequest):
    def __init__(self, project_name: str, region: str, description: str = None):
        self.project_name = project_name
        self.region = region
        self.description = description


class DeleteProjectRequest(TLSRequest):
    def __init__(self, project_id: str):
        self.project_id = project_id


class ModifyProjectRequest(TLSRequest):
    def __init__(self, project_id: str, project_name: str = None, description: str = None):
        self.project_id = project_id
        self.project_name = project_name
        self.description = description


class DescribeProjectRequest(TLSRequest):
    def __init__(self, project_id: str):
        self.project_id = project_id


class DescribeProjectsRequest(TLSRequest):
    def __init__(self, page_number: int = 1, page_size: int = 20,
                 project_name: str = None, project_id: str = None, is_full_name: bool = False):
        self.page_number = page_number
        self.page_size = page_size
        self.project_name = project_name
        self.project_id = project_id
        self.is_full_name = is_full_name


class CreateTopicRequest(TLSRequest):
    def __init__(self, topic_name: str, project_id: str, ttl: int, shard_count: int, description: str = None):
        self.topic_name = topic_name
        self.project_id = project_id
        self.ttl = ttl
        self.shard_count = shard_count
        self.description = description


class DeleteTopicRequest(TLSRequest):
    def __init__(self, topic_id: str):
        self.topic_id = topic_id


class ModifyTopicRequest(TLSRequest):
    def __init__(self, topic_id: str, topic_name: str = None, ttl: int = None, description: str = None):
        self.topic_id = topic_id
        self.topic_name = topic_name
        self.ttl = ttl
        self.description = description


class DescribeTopicRequest(TLSRequest):
    def __init__(self, topic_id: str):
        self.topic_id = topic_id


class DescribeTopicsRequest(TLSRequest):
    def __init__(self, project_id: str, page_number: int = 1, page_size: int = 20,
                 topic_name: str = None, topic_id: str = None, is_full_name: bool = False):
        self.project_id = project_id
        self.page_number = page_number
        self.page_size = page_size
        self.topic_name = topic_name
        self.topic_id = topic_id
        self.is_full_name = is_full_name


class SetIndexRequest(TLSRequest):
    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None):
        self.topic_id = topic_id
        self.full_text = full_text
        self.key_value = key_value

    def get_api_input(self):
        body = {TOPIC_ID: self.topic_id}

        if self.full_text is not None:
            body[FULL_TEXT] = self.full_text.json()
        if self.key_value is not None:
            body[KEY_VALUE] = []
            for key_value_info in self.key_value:
                body[KEY_VALUE].append(key_value_info.json())

        return body


class CreateIndexRequest(SetIndexRequest):
    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None):
        super(CreateIndexRequest, self).__init__(topic_id, full_text, key_value)


class DeleteIndexRequest(TLSRequest):
    def __init__(self, topic_id: str):
        self.topic_id = topic_id


class ModifyIndexRequest(SetIndexRequest):
    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None):
        super(ModifyIndexRequest, self).__init__(topic_id, full_text, key_value)


class DescribeIndexRequest(TLSRequest):
    def __init__(self, topic_id: str):
        self.topic_id = topic_id


class PutLogsRequest(TLSRequest):
    def __init__(self, topic_id: str, log_group_list: LogGroupList, hash_key: str = None, compression: str = None):
        self.topic_id = topic_id
        self.log_group_list = log_group_list
        self.hash_key = hash_key
        self.compression = compression

    def get_api_input(self):
        pb_log_group_list = self.log_group_list.SerializeToString()

        if len(pb_log_group_list) > 5 * 1024 * 1024:
            raise TLSException(error_code="LogGroupListSizeTooLarge",
                               error_message="The size of LogGroupList exceeds 5 MB.")

        params = {TOPIC_ID: self.topic_id}
        body = {DATA: pb_log_group_list}
        request_headers = {CONTENT_TYPE: APPLICATION_X_PROTOBUF, X_TLS_BODYRAWSIZE: str(len(pb_log_group_list))}

        if self.hash_key is not None:
            request_headers[X_TLS_HASHKEY] = self.hash_key
        if self.compression is not None:
            request_headers[X_TLS_COMPRESSTYPE] = self.compression
            if self.compression == LZ4:
                if lz4 is None:
                    raise TLSException(error_code="UnsupportedLZ4",
                                       error_message="Your platform does not support the LZ4 compression package.")
                body[DATA] = lz4.compress(body[DATA])[4:]

        return {PARAMS: params, BODY: body, REQUEST_HEADERS: request_headers}


class DescribeCursorRequest(TLSRequest):
    def __init__(self, topic_id: str, shard_id: int, from_time: str):
        self.topic_id = topic_id
        self.shard_id = shard_id
        self.from_time = from_time

    def get_api_input(self):
        params = {TOPIC_ID: self.topic_id, SHARD_ID: self.shard_id}
        body = {FROM: self.from_time}

        return {PARAMS: params, BODY: body}


class ConsumeLogsRequest(TLSRequest):
    def __init__(self, topic_id: str, shard_id: int, cursor: str, end_cursor: str = None,
                 log_group_count: int = None, compression: str = None):
        self.topic_id = topic_id
        self.shard_id = shard_id
        self.cursor = cursor
        self.end_cursor = end_cursor
        self.log_group_count = log_group_count
        self.compression = compression

    def get_api_input(self):
        params = {TOPIC_ID: self.topic_id, SHARD_ID: self.shard_id}
        body = {CURSOR: self.cursor}

        if self.end_cursor is not None:
            body[END_CURSOR] = self.end_cursor
        if self.log_group_count is not None:
            body[LOG_GROUP_COUNT] = self.log_group_count
        if self.compression is not None:
            if self.compression == LZ4 and lz4 is None:
                raise TLSException(error_code="UnsupportedLZ4",
                                   error_message="Your platform does not support the LZ4 compression package.")
            body[COMPRESSION] = self.compression

        return {PARAMS: params, BODY: body}


class SearchLogsRequest(TLSRequest):
    def __init__(self, topic_id: str, query: str, start_time: int, end_time: int, limit: int = None,
                 context: str = None, sort: str = DESC):
        self.topic_id = topic_id
        self.query = query
        self.start_time = start_time
        self.end_time = end_time
        self.limit = limit
        self.context = context
        self.sort = sort


class DescribeLogContextRequest(TLSRequest):
    def __init__(self, topic_id: str, context_flow: str, package_offset: int, source: str,
                 prev_logs: int = 10, next_logs: int = 10):
        self.topic_id = topic_id
        self.context_flow = context_flow
        self.package_offset = package_offset
        self.source = source
        self.prev_logs = prev_logs
        self.next_logs = next_logs


class WebTracksRequest(TLSRequest):
    def __init__(self, project_id: str, topic_id: str, logs: List[Dict], source: str = None, compression: str = None):
        self.project_id = project_id
        self.topic_id = topic_id
        self.logs = logs
        self.source = source
        self.compression = compression

    def get_api_input(self):
        if len(self.logs) > 10000:
            raise TLSException(error_code="LogGroupSizeTooLarge",
                               error_message="The size of LogGroup exceeds 10000.")

        params = {PROJECT_ID: self.project_id, TOPIC_ID: self.topic_id}
        body = {LOGS: self.logs}

        if self.source is not None:
            body[SOURCE] = self.source

        request_headers = {CONTENT_TYPE: APPLICATION_JSON, X_TLS_BODYRAWSIZE: str(len(json.dumps(body)))}
        body[DATA] = json.dumps(body)

        if self.compression is not None:
            request_headers[X_TLS_COMPRESSTYPE] = self.compression
            if self.compression == LZ4:
                body[DATA] = lz4.compress(body[DATA])[4:]

        return {PARAMS: params, BODY: body, REQUEST_HEADERS: request_headers}


class DescribeHistogramRequest(TLSRequest):
    def __init__(self, topic_id: str, query: str, start_time: int, end_time: int, interval: int = None):
        self.topic_id = topic_id
        self.query = query
        self.start_time = start_time
        self.end_time = end_time
        self.interval = interval


class CreateDownloadTaskRequest(TLSRequest):
    def __init__(self, task_name: str, topic_id: str, query: str, start_time: int, end_time: int,
                 data_format: str, sort: str, limit: int, compression: str):
        self.task_name = task_name
        self.topic_id = topic_id
        self.query = query
        self.start_time = start_time
        self.end_time = end_time
        self.data_format = data_format
        self.sort = sort
        self.limit = limit
        self.compression = compression


class DescribeDownloadTasksRequest(TLSRequest):
    def __init__(self, topic_id: str, page_number: int = 1, page_size: int = 20):
        self.topic_id = topic_id
        self.page_number = page_number
        self.page_size = page_size


class DescribeDownloadUrlRequest(TLSRequest):
    def __init__(self, task_id: str):
        self.task_id = task_id


class DescribeShardsRequest(TLSRequest):
    def __init__(self, topic_id: str, page_number: int = 1, page_size: int = 20):
        self.topic_id = topic_id
        self.page_number = page_number
        self.page_size = page_size


class CreateHostGroupRequest(TLSRequest):
    def __init__(self, host_group_name: str, host_group_type: str,
                 host_ip_list: List[str] = None, host_identifier: str = None, auto_update: bool = False,
                 update_start_time: str = None, update_end_time: str = None):
        self.host_group_name = host_group_name
        self.host_group_type = host_group_type
        self.host_ip_list = host_ip_list
        self.host_identifier = host_identifier
        self.auto_update = auto_update
        self.update_start_time = update_start_time
        self.update_end_time = update_end_time


class DeleteHostGroupRequest(TLSRequest):
    def __init__(self, host_group_id: str):
        self.host_group_id = host_group_id


class ModifyHostGroupRequest(TLSRequest):
    def __init__(self, host_group_id: str, host_group_name: str = None, host_group_type: str = None,
                 host_ip_list: List[str] = None, host_identifier: str = None, auto_update: bool = False,
                 update_start_time: str = None, update_end_time: str = None):
        self.host_group_id = host_group_id
        self.host_group_name = host_group_name
        self.host_group_type = host_group_type
        self.host_ip_list = host_ip_list
        self.host_identifier = host_identifier
        self.auto_update = auto_update
        self.update_start_time = update_start_time
        self.update_end_time = update_end_time


class DescribeHostGroupRequest(TLSRequest):
    def __init__(self, host_group_id: str):
        self.host_group_id = host_group_id


class DescribeHostGroupsRequest(TLSRequest):
    def __init__(self, host_group_id: str = None, host_group_name: str = None,
                 page_number: int = 1, page_size: int = 20):
        self.host_group_id = host_group_id
        self.host_group_name = host_group_name
        self.page_number = page_number
        self.page_size = page_size


class DescribeHostsRequest(TLSRequest):
    def __init__(self, host_group_id: str, ip: str = None, heartbeat_status: int = None,
                 page_number: int = 1, page_size: int = 20):
        self.host_group_id = host_group_id
        self.ip = ip
        self.heartbeat_status = heartbeat_status
        self.page_number = page_number
        self.page_size = page_size


class DeleteHostRequest(TLSRequest):
    def __init__(self, host_group_id: str, ip: str):
        self.host_group_id = host_group_id
        self.ip = ip


class DescribeHostGroupRulesRequest(TLSRequest):
    def __init__(self, host_group_id: str, page_number: int = 1, page_size: int = 20):
        self.host_group_id = host_group_id
        self.page_number = page_number
        self.page_size = page_size


class ModifyHostGroupsAutoUpdateRequest(TLSRequest):
    def __init__(self, host_group_ids: List[str], auto_update: bool = False,
                 update_start_time: str = None, update_end_time: str = None):
        self.host_group_ids = host_group_ids
        self.auto_update = auto_update
        self.update_start_time = update_start_time
        self.update_end_time = update_end_time


class SetRuleRequest(TLSRequest):
    def __init__(self, rule_name: str = None, paths: List[str] = None, log_type: str = None,
                 extract_rule: ExtractRule = None, exclude_paths: List[ExcludePath] = None,
                 user_define_rule: UserDefineRule = None, log_sample: str = None, input_type: int = None,
                 container_rule: ContainerRule = None):
        self.rule_name = rule_name
        self.paths = paths
        self.log_type = log_type
        self.extract_rule = extract_rule
        self.exclude_paths = exclude_paths
        self.user_define_rule = user_define_rule
        self.log_sample = log_sample
        self.input_type = input_type
        self.container_rule = container_rule

    def get_api_input(self):
        body = {}

        if self.rule_name is not None:
            body[RULE_NAME] = self.rule_name
        if self.paths is not None:
            body[PATHS] = self.paths
        if self.log_type is not None:
            body[LOG_TYPE] = self.log_type
        if self.input_type is not None:
            body[INPUT_TYPE] = self.input_type
        if self.extract_rule is not None:
            body[EXTRACT_RULE] = self.extract_rule.json()
        if self.exclude_paths is not None:
            body[EXCLUDE_PATHS] = []
            for exclude_path in self.exclude_paths:
                body[EXCLUDE_PATHS].append(exclude_path.json())
        if self.user_define_rule is not None:
            body[USER_DEFINE_RULE] = self.user_define_rule.json()
        if self.log_sample is not None:
            body[LOG_SAMPLE] = self.log_sample
        if self.container_rule is not None:
            body[CONTAINER_RULE] = self.container_rule.json()

        return body


class CreateRuleRequest(SetRuleRequest):
    def __init__(self, topic_id: str, rule_name: str, paths: List[str] = None, log_type: str = "minimalist_log",
                 extract_rule: ExtractRule = None, exclude_paths: List[ExcludePath] = None,
                 user_define_rule: UserDefineRule = None, log_sample: str = None, input_type: int = 0,
                 container_rule: ContainerRule = None):
        super(CreateRuleRequest, self).__init__(rule_name, paths, log_type, extract_rule, exclude_paths,
                                                user_define_rule, log_sample, input_type, container_rule)

        self.topic_id = topic_id

    def get_api_input(self):
        body = super(CreateRuleRequest, self).get_api_input()
        body[TOPIC_ID] = self.topic_id

        return body


class DeleteRuleRequest(TLSRequest):
    def __init__(self, rule_id: str):
        self.rule_id = rule_id


class ModifyRuleRequest(SetRuleRequest):
    def __init__(self, rule_id: str, rule_name: str = None, paths: List[str] = None, log_type: str = None,
                 extract_rule: ExtractRule = None, exclude_paths: List[ExcludePath] = None,
                 user_define_rule: UserDefineRule = None, log_sample: str = None, input_type: int = None,
                 container_rule: ContainerRule = None):
        super(ModifyRuleRequest, self).__init__(rule_name, paths, log_type, extract_rule, exclude_paths,
                                                user_define_rule, log_sample, input_type, container_rule)

        self.rule_id = rule_id

    def get_api_input(self):
        body = super(ModifyRuleRequest, self).get_api_input()
        body[RULE_ID] = self.rule_id

        return body


class DescribeRuleRequest(TLSRequest):
    def __init__(self, rule_id: str):
        self.rule_id = rule_id


class DescribeRulesRequest(TLSRequest):
    def __init__(self, project_id: str, rule_id: str = None, rule_name: str = None,
                 topic_id: str = None, topic_name: str = None, page_number: int = 1, page_size: int = 20):
        self.project_id = project_id
        self.rule_id = rule_id
        self.rule_name = rule_name
        self.topic_id = topic_id
        self.topic_name = topic_name
        self.page_number = page_number
        self.page_size = page_size


class ApplyRuleToHostGroupsRequest(TLSRequest):
    def __init__(self, rule_id: str, host_group_ids: List[str]):
        self.rule_id = rule_id
        self.host_group_ids = host_group_ids


class DeleteRuleFromHostGroupsRequest(TLSRequest):
    def __init__(self, rule_id: str, host_group_ids: List[str]):
        self.rule_id = rule_id
        self.host_group_ids = host_group_ids


class CreateAlarmNotifyGroupRequest(TLSRequest):
    def __init__(self, alarm_notify_group_name: str, notify_type: List[str], receivers: List[Receiver]):
        self.alarm_notify_group_name = alarm_notify_group_name
        self.notify_type = notify_type
        self.receivers = receivers

    def get_api_input(self):
        body = {ALARM_NOTIFY_GROUP_NAME: self.alarm_notify_group_name, NOTIFY_TYPE: self.notify_type, RECEIVERS: []}

        for receiver in self.receivers:
            body[RECEIVERS].append(receiver.json())

        return body


class DeleteAlarmNotifyGroupRequest(TLSRequest):
    def __init__(self, alarm_notify_group_id: str):
        self.alarm_notify_group_id = alarm_notify_group_id


class ModifyAlarmNotifyGroupRequest(TLSRequest):
    def __init__(self, alarm_notify_group_id: str, alarm_notify_group_name: str = None,
                 notify_type: List[str] = None, receivers: List[Receiver] = None):
        self.alarm_notify_group_id = alarm_notify_group_id
        self.alarm_notify_group_name = alarm_notify_group_name
        self.notify_type = notify_type
        self.receivers = receivers

    def get_api_input(self):
        body = {ALARM_NOTIFY_GROUP_ID: self.alarm_notify_group_id}

        if self.alarm_notify_group_name is not None:
            body[ALARM_NOTIFY_GROUP_NAME] = self.alarm_notify_group_name
        if self.notify_type is not None:
            body[NOTIFY_TYPE] = self.notify_type
        if self.receivers is not None:
            body[RECEIVERS] = []
            for receiver in self.receivers:
                body[RECEIVERS].append(receiver.json())

        return body


class DescribeAlarmNotifyGroupsRequest(TLSRequest):
    def __init__(self, alarm_notify_group_name: str = None, alarm_notify_group_id: str = None,
                 receiver_name: str = None, page_number: int = 1, page_size: int = 20):
        self.alarm_notify_group_name = alarm_notify_group_name
        self.alarm_notify_group_id = alarm_notify_group_id
        self.receiver_name = receiver_name
        self.page_number = page_number
        self.page_size = page_size


class SetAlarmRequest(TLSRequest):
    def __init__(self, alarm_name: str = None, query_request: List[QueryRequest] = None,
                 request_cycle: RequestCycle = None, condition: str = None, alarm_period: int = None,
                 alarm_notify_group: List[str] = None, status: bool = None, trigger_period: int = None,
                 user_define_msg: str = None):
        self.alarm_name = alarm_name
        self.query_request = query_request
        self.request_cycle = request_cycle
        self.condition = condition
        self.alarm_period = alarm_period
        self.alarm_notify_group = alarm_notify_group
        self.status = status
        self.trigger_period = trigger_period
        self.user_define_msg = user_define_msg

    def get_api_input(self):
        body = super(SetAlarmRequest, self).get_api_input()

        if self.request_cycle is not None:
            body[REQUEST_CYCLE] = self.request_cycle.json()
        if self.query_request is not None:
            body[QUERY_REQUEST] = []
            for one_query_request in self.query_request:
                body[QUERY_REQUEST].append(one_query_request.json())

        return body


class CreateAlarmRequest(SetAlarmRequest):
    def __init__(self, project_id: str, alarm_name: str, query_request: List[QueryRequest],
                 request_cycle: RequestCycle, condition: str, alarm_period: int, alarm_notify_group: List[str],
                 status: bool = True, trigger_period: int = 1, user_define_msg: str = None):
        super(CreateAlarmRequest, self).__init__(alarm_name, query_request, request_cycle, condition, alarm_period,
                                                 alarm_notify_group, status, trigger_period, user_define_msg)
        self.project_id = project_id


class DeleteAlarmRequest(TLSRequest):
    def __init__(self, alarm_id: str):
        self.alarm_id = alarm_id


class ModifyAlarmRequest(SetAlarmRequest):
    def __init__(self, alarm_id: str, alarm_name: str = None, query_request: List[QueryRequest] = None,
                 request_cycle: RequestCycle = None, condition: str = None, alarm_period: int = None,
                 alarm_notify_group: List[str] = None, status: bool = None, trigger_period: int = None,
                 user_define_msg: str = None):
        super(ModifyAlarmRequest, self).__init__(alarm_name, query_request, request_cycle, condition, alarm_period,
                                                 alarm_notify_group, status, trigger_period, user_define_msg)
        self.alarm_id = alarm_id


class DescribeAlarmsRequest(TLSRequest):
    def __init__(self, project_id: str, alarm_name: str = None, alarm_id: str = None, topic_name: str = None,
                 topic_id: str = None, status: bool = None, page_number: int = 1, page_size: int = 20):
        self.project_id = project_id
        self.alarm_name = alarm_name
        self.alarm_id = alarm_id
        self.topic_name = topic_name
        self.topic_id = topic_id
        self.status = status
        self.page_number = page_number
        self.page_size = page_size


class OpenKafkaConsumerRequest(TLSRequest):
    def __init__(self, topic_id: str):
        self.topic_id = topic_id


class CloseKafkaConsumerRequest(TLSRequest):
    def __init__(self, topic_id: str):
        self.topic_id = topic_id


class DescribeKafkaConsumerRequest(TLSRequest):
    def __init__(self, topic_id: str):
        self.topic_id = topic_id



# coding:utf-8
import json
import threading
from urllib.parse import urlparse

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service


class BioOsService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(BioOsService, '_instance'):
            with BioOsService._instance_lock:
                if not hasattr(BioOsService, '_instance'):
                    BioOsService._instance = object.__new__(cls)
        return BioOsService._instance

    def __init__(self, endpoint='https://open.volcengineapi.com', region='cn-beijing'):
        self.service_info = BioOsService.get_service_info(endpoint, region)
        self.api_info = BioOsService.get_api_info()
        super(BioOsService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(endpoint, region):
        parsed = urlparse(endpoint)
        scheme, hostname = parsed.scheme, parsed.hostname
        if not scheme or not hostname:
            raise Exception(f'invalid endpoint format: {endpoint}')
        service_info = ServiceInfo(hostname, {'Accept': 'application/json'},
                                   Credentials('', '', 'bio', region), 5, 5, scheme=scheme)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            'CreateWorkspace':
                ApiInfo('POST', '/', {'Action': 'CreateWorkspace', 'Version': '2021-03-04'}, {}, {}),
            'ListWorkspaces':
                ApiInfo('POST', '/', {'Action': 'ListWorkspaces', 'Version': '2021-03-04'}, {}, {}),
            'UpdateWorkspace':
                ApiInfo('POST', '/', {'Action': 'UpdateWorkspace', 'Version': '2021-03-04'}, {}, {}),
            'DeleteWorkspace':
                ApiInfo('POST', '/', {'Action': 'DeleteWorkspace', 'Version': '2021-03-04'}, {}, {}),
            'BindClusterToWorkspace':
                ApiInfo('POST', '/', {'Action': 'BindClusterToWorkspace', 'Version': '2021-03-04'}, {}, {}),
            'UnbindClusterAndWorkspace':
                ApiInfo('POST', '/', {'Action': 'UnbindClusterAndWorkspace', 'Version': '2021-03-04'}, {}, {}),
            'ListClustersOfWorkspace':
                ApiInfo('POST', '/', {'Action': 'ListClustersOfWorkspace', 'Version': '2021-03-04'}, {}, {}),
            'CreateCluster':
                ApiInfo('POST', '/', {'Action': 'CreateCluster', 'Version': '2021-03-04'}, {}, {}),
            'ListClusters':
                ApiInfo('POST', '/', {'Action': 'ListClusters', 'Version': '2021-03-04'}, {}, {}),
            'DeleteCluster':
                ApiInfo('POST', '/', {'Action': 'DeleteCluster', 'Version': '2021-03-04'}, {}, {}),
            'CreateDataModel':
                ApiInfo('POST', '/', {'Action': 'CreateDataModel', 'Version': '2021-03-04'}, {}, {}),
            'ListDataModels':
                ApiInfo('POST', '/', {'Action': 'ListDataModels', 'Version': '2021-03-04'}, {}, {}),
            'ListDataModelRows':
                ApiInfo('POST', '/', {'Action': 'ListDataModelRows', 'Version': '2021-03-04'}, {}, {}),
            'DeleteDataModelRowsAndHeaders':
                ApiInfo('POST', '/', {'Action': 'DeleteDataModelRowsAndHeaders', 'Version': '2021-03-04'}, {}, {}),
            'CreateSubmission':
                ApiInfo('POST', '/', {'Action': 'CreateSubmission', 'Version': '2021-03-04'}, {}, {}),
            'ListSubmissions':
                ApiInfo('POST', '/', {'Action': 'ListSubmissions', 'Version': '2021-03-04'}, {}, {}),
            'DeleteSubmission':
                ApiInfo('POST', '/', {'Action': 'DeleteSubmission', 'Version': '2021-03-04'}, {}, {}),
            'ListRuns':
                ApiInfo('POST', '/', {'Action': 'ListRuns', 'Version': '2021-03-04'}, {}, {}),
            'ListTasks':
                ApiInfo('POST', '/', {'Action': 'ListTasks', 'Version': '2021-03-04'}, {}, {}),
            'CreateWorkflow':
                ApiInfo('POST', '/', {'Action': 'CreateWorkflow', 'Version': '2021-03-04'}, {}, {}),
            'ListWorkflows':
                ApiInfo('POST', '/', {'Action': 'ListWorkflows', 'Version': '2021-03-04'}, {}, {}),
            'UpdateWorkflow':
                ApiInfo('POST', '/', {'Action': 'UpdateWorkflow', 'Version': '2021-03-04'}, {}, {}),
            'DeleteWorkflow':
                ApiInfo('POST', '/', {'Action': 'DeleteWorkflow', 'Version': '2021-03-04'}, {}, {}),
        }
        return api_info

    def create_workspaces(self, params):
        return self.__request('CreateWorkspace', params)

    def list_workspaces(self, params):
        return self.__request('ListWorkspaces', params)

    def update_workspace(self, params):
        return self.__request('UpdateWorkspace', params)

    def delete_workspace(self, params):
        return self.__request('DeleteWorkspace', params)

    def bind_cluster_to_workspace(self, params):
        return self.__request('BindClusterToWorkspace', params)

    def unbind_cluster_and_workspace(self, params):
        return self.__request('UnbindClusterAndWorkspace', params)

    def list_clusters_of_workspace(self, params):
        return self.__request('ListClustersOfWorkspace', params)

    def create_cluster(self, params):
        return self.__request('CreateCluster', params)

    def list_clusters(self, params):
        return self.__request('ListClusters', params)

    def delete_cluster(self, params):
        return self.__request('DeleteCluster', params)

    def create_data_model(self, params):
        return self.__request('CreateDataModel', params)

    def list_data_models(self, params):
        return self.__request('ListDataModels', params)

    def list_data_model_rows(self, params):
        return self.__request('ListDataModelRows', params)

    def delete_data_model_rows_and_headers(self, params):
        return self.__request('DeleteDataModelRowsAndHeaders', params)

    def create_submission(self, params):
        return self.__request('CreateSubmission', params)

    def list_submissions(self, params):
        return self.__request('ListSubmissions', params)

    def delete_submission(self, params):
        return self.__request('DeleteSubmission', params)

    def list_runs(self, params):
        return self.__request('ListRuns', params)

    def list_tasks(self, params):
        return self.__request('ListTasks', params)

    def create_workflow(self, params):
        return self.__request('CreateWorkflow', params)

    def list_workflows(self, params):
        return self.__request('ListWorkflows', params)

    def update_workflow(self, params):
        return self.__request('UpdateWorkflow', params)

    def delete_workflow(self, params):
        return self.__request('DeleteWorkflow', params)

    def __request(self, action, params):
        res = self.json(action, dict(), json.dumps(params))
        if res == '':
            raise Exception('empty response')
        res_json = json.loads(res)
        if 'Result' not in res_json.keys():
            return res_json
        return res_json['Result']



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from volcengine.tls.TLSService import TLSService
from volcengine.tls.tls_requests import *


if __name__ == "__main__":
    # 请查询控制台，填写以下参数值
    endpoint = ""
    access_key_id = ""
    access_key_secret = ""
    region = ""

    # 实例化TLS客户端
    tls_service = TLSService(endpoint, access_key_id, access_key_secret, region)

    # 创建日志项目
    create_project_request = CreateProjectRequest(project_name="project-name", region=region,
                                                  description="project-description")
    create_project_response = tls_service.create_project(create_project_request)
    project_id = create_project_response.project_id

    # 创建日志主题
    create_topic_request = CreateTopicRequest(topic_name="topic-name", project_id=project_id,
                                              ttl=3650, description="topic-description", shard_count=2)
    create_topic_response = tls_service.create_topic(create_topic_request)
    topic_id = create_topic_response.topic_id

    # 创建索引配置
    full_text = FullTextInfo(case_sensitive=False, delimiter=",-;", include_chinese=False)
    value_info_a = ValueInfo(value_type="text", delimiter="", case_sensitive=True,
                             include_chinese=False, sql_flag=False)
    value_info_b = ValueInfo(value_type="long", delimiter="", case_sensitive=False,
                             include_chinese=False, sql_flag=True)
    key_value_info_a = KeyValueInfo(key="test1", value=value_info_a)
    key_value_info_b = KeyValueInfo(key="test2", value=value_info_b)
    key_value = [key_value_info_a, key_value_info_b]
    create_index_request = CreateIndexRequest(topic_id=create_topic_response.topic_id, full_text=full_text,
                                              key_value=key_value)
    create_index_response = tls_service.create_index(create_index_request)

    # 查询索引配置
    describe_index_request = DescribeIndexRequest(topic_id)
    describe_index_response = tls_service.describe_index(describe_index_request)

    # 修改索引配置
    modify_index_request = ModifyIndexRequest(topic_id, full_text=FullTextInfo(case_sensitive=True, delimiter=","))
    modify_index_response = tls_service.modify_index(modify_index_request)

    # 删除索引配置
    delete_index_request = DeleteIndexRequest(topic_id)
    delete_index_response = tls_service.delete_index(delete_index_request)



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.live_requests import CreateVQScoreTaskRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    req = CreateVQScoreTaskRequest()
    req.MainAddr = ''
    req.ContrastAddr = ''
    req.FrameInterval = 0
    req.Duration = 700
    req.Algorithm = ''

    print(req.__dict__)
    resp = live_service.create_v_q_score_task(req)
    print(resp)



# coding:utf-8
from volcengine.vms.risk import RiskService

if __name__ == '__main__':
    riskService = RiskService()

    RiskService.set_ak("")
    RiskService.set_sk("")

    query_call_call_form = {
        "CustomerNumberList": "188xxxx1647",
        "BusinessLineId": "200000001",
        "CallType": 1,
    }
    print(RiskService.query_call_call(query_call_call_form))



# coding:utf-8
from __future__ import print_function

import json

from volcengine.const.Const import REGION_AP_SINGAPORE1
from volcengine.sms.SmsService import SmsService

if __name__ == '__main__':
    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)
    # cn
    sms_service = SmsService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_scheme("http")
    # sms_service.set_scheme("https")
    # sms_service.set_host('host')

    body = {
        "SmsAccount": "subAccount",
        "Sign": "signature",
        "From": "BytePlus",
        "TemplateID": "ST_xxx",
        "Messages": [{"TemplateParam": "{\"code\": \"1234\"}", "PhoneNumber": "+65xxxxxxxx"}],
        "Tag": "tag",
    }
    resp = sms_service.send_batch_sms(body)
    print(resp)



# coding:utf-8
from __future__ import print_function

from volcengine.bioos.BioOsService import BioOsService

if __name__ == '__main__':
    # set endpoint/region here if the default value is unsatisfied
    bioos_service = BioOsService(endpoint='endpoint', region='region')

    # call below method if you don't set ak and sk in $HOME/.volc/config
    bioos_service.set_ak('ak')
    bioos_service.set_sk('sk')

    params = {
    }

    resp = bioos_service.delete_workspace(params)
    print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/response/response_live.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.base.models.base import base_pb2 as base_dot_base__pb2
from volcengine.live.models.business import domain_pb2 as live_dot_business_dot_domain__pb2
from volcengine.live.models.business import VQScore_pb2 as live_dot_business_dot_VQScore__pb2
from volcengine.live.models.business import addr_pb2 as live_dot_business_dot_addr__pb2
from volcengine.live.models.business import pull_to_push_pb2 as live_dot_business_dot_pull__to__push__pb2
from volcengine.live.models.business import deny_config_pb2 as live_dot_business_dot_deny__config__pb2
from volcengine.live.models.business import relay_source_pb2 as live_dot_business_dot_relay__source__pb2
from volcengine.live.models.business import stream_manage_pb2 as live_dot_business_dot_stream__manage__pb2
from volcengine.live.models.business import snapshot_manage_pb2 as live_dot_business_dot_snapshot__manage__pb2
from volcengine.live.models.business import record_manage_pb2 as live_dot_business_dot_record__manage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!live/response/response_live.proto\x12\x1fVolcengine.Live.Models.Response\x1a\x0f\x62\x61se/base.proto\x1a\x1alive/business/domain.proto\x1a\x1blive/business/VQScore.proto\x1a\x18live/business/addr.proto\x1a live/business/pull_to_push.proto\x1a\x1flive/business/deny_config.proto\x1a live/business/relay_source.proto\x1a!live/business/stream_manage.proto\x1a#live/business/snapshot_manage.proto\x1a!live/business/record_manage.proto\"_\n\x14\x43reateDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xa4\x01\n\x18ListDomainDetailResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Live.Models.Business.DomainListInfo\"`\n\x15\x44isableDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"_\n\x14\x45nableDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"_\n\x14\x44\x65leteDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xa2\x01\n\x16\x44\x65scribeDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Live.Models.Business.DomainListInfo\"l\n!ManagerPullPushDomainBindResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xb0\x01\n$DescribeLiveStreamInfoByPageResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Live.Models.Business.LiveStreamInfo\"\xb4\x01\n&DescribeClosedStreamInfoByPageResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x41\n\x06Result\x18\x02 \x01(\x0b\x32\x31.Volcengine.Live.Models.Business.ClosedStreamInfo\"\xac\x01\n\x1f\x44\x65scribeLiveStreamStateResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Live.Models.Business.StreamStateInfo\"]\n\x12KillStreamResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"_\n\x14\x46orbidStreamResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xba\x01\n)DescribeForbiddenStreamInfoByPageResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Live.Models.Business.ForbiddenStreamInfo\"_\n\x14ResumeStreamResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xb6\x01\n\"DescribeCDNSnapshotHistoryResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12G\n\x06Result\x18\x02 \x01(\x0b\x32\x37.Volcengine.Live.Models.Business.CDNSnapshotHistoryInfo\"\xb4\x01\n%DescribeRecordTaskFileHistoryResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Live.Models.Business.RecordHistoryInfo\"d\n\x19UpdateRelaySourceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"d\n\x19\x44\x65leteRelaySourceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xae\x01\n\x1b\x44\x65scribeRelaySourceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Live.Models.Business.RelaySourceConfigList\"\xa0\x01\n\x19\x43reateVQScoreTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12:\n\x06Result\x18\x02 \x01(\x0b\x32*.Volcengine.Live.Models.Business.VQScoreID\"\xa4\x01\n\x1b\x44\x65scribeVQScoreTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Live.Models.Business.VQScoreInfo\"\xa8\x01\n\x17ListVQScoreTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Live.Models.Business.VQScoreTaskListInfo\"\xaa\x01\n\x17GeneratePlayURLResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Live.Models.Business.GeneratePlayURLResult\"\xaa\x01\n\x17GeneratePushURLResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Live.Models.Business.GeneratePushURLResult\"\xb4\x01\n\x1c\x43reatePullToPushTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Live.Models.Business.CreatePullToPushTaskResult\"\xb0\x01\n\x1aListPullToPushTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Live.Models.Business.ListPullToPushTaskResult\"g\n\x1cUpdatePullToPushTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"h\n\x1dRestartPullToPushTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"e\n\x1aStopPullToPushTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"g\n\x1c\x44\x65letePullToPushTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"c\n\x18UpdateDenyConfigResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xb0\x01\n\x1a\x44\x65scribeDenyConfigResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Live.Models.Business.DescribeDenyConfigResult\"c\n\x18\x44\x65leteDenyConfigResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadataB\xd1\x01\n*com.volcengine.service.live.model.responseB\x0cLiveResponseP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/response\xa0\x01\x01\xd8\x01\x01\xca\x02!Volc\\Service\\Live\\Models\\Response\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_CREATEDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['CreateDomainResponse']
_LISTDOMAINDETAILRESPONSE = DESCRIPTOR.message_types_by_name['ListDomainDetailResponse']
_DISABLEDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['DisableDomainResponse']
_ENABLEDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['EnableDomainResponse']
_DELETEDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDomainResponse']
_DESCRIBEDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['DescribeDomainResponse']
_MANAGERPULLPUSHDOMAINBINDRESPONSE = DESCRIPTOR.message_types_by_name['ManagerPullPushDomainBindResponse']
_DESCRIBELIVESTREAMINFOBYPAGERESPONSE = DESCRIPTOR.message_types_by_name['DescribeLiveStreamInfoByPageResponse']
_DESCRIBECLOSEDSTREAMINFOBYPAGERESPONSE = DESCRIPTOR.message_types_by_name['DescribeClosedStreamInfoByPageResponse']
_DESCRIBELIVESTREAMSTATERESPONSE = DESCRIPTOR.message_types_by_name['DescribeLiveStreamStateResponse']
_KILLSTREAMRESPONSE = DESCRIPTOR.message_types_by_name['KillStreamResponse']
_FORBIDSTREAMRESPONSE = DESCRIPTOR.message_types_by_name['ForbidStreamResponse']
_DESCRIBEFORBIDDENSTREAMINFOBYPAGERESPONSE = DESCRIPTOR.message_types_by_name['DescribeForbiddenStreamInfoByPageResponse']
_RESUMESTREAMRESPONSE = DESCRIPTOR.message_types_by_name['ResumeStreamResponse']
_DESCRIBECDNSNAPSHOTHISTORYRESPONSE = DESCRIPTOR.message_types_by_name['DescribeCDNSnapshotHistoryResponse']
_DESCRIBERECORDTASKFILEHISTORYRESPONSE = DESCRIPTOR.message_types_by_name['DescribeRecordTaskFileHistoryResponse']
_UPDATERELAYSOURCERESPONSE = DESCRIPTOR.message_types_by_name['UpdateRelaySourceResponse']
_DELETERELAYSOURCERESPONSE = DESCRIPTOR.message_types_by_name['DeleteRelaySourceResponse']
_DESCRIBERELAYSOURCERESPONSE = DESCRIPTOR.message_types_by_name['DescribeRelaySourceResponse']
_CREATEVQSCORETASKRESPONSE = DESCRIPTOR.message_types_by_name['CreateVQScoreTaskResponse']
_DESCRIBEVQSCORETASKRESPONSE = DESCRIPTOR.message_types_by_name['DescribeVQScoreTaskResponse']
_LISTVQSCORETASKRESPONSE = DESCRIPTOR.message_types_by_name['ListVQScoreTaskResponse']
_GENERATEPLAYURLRESPONSE = DESCRIPTOR.message_types_by_name['GeneratePlayURLResponse']
_GENERATEPUSHURLRESPONSE = DESCRIPTOR.message_types_by_name['GeneratePushURLResponse']
_CREATEPULLTOPUSHTASKRESPONSE = DESCRIPTOR.message_types_by_name['CreatePullToPushTaskResponse']
_LISTPULLTOPUSHTASKRESPONSE = DESCRIPTOR.message_types_by_name['ListPullToPushTaskResponse']
_UPDATEPULLTOPUSHTASKRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePullToPushTaskResponse']
_RESTARTPULLTOPUSHTASKRESPONSE = DESCRIPTOR.message_types_by_name['RestartPullToPushTaskResponse']
_STOPPULLTOPUSHTASKRESPONSE = DESCRIPTOR.message_types_by_name['StopPullToPushTaskResponse']
_DELETEPULLTOPUSHTASKRESPONSE = DESCRIPTOR.message_types_by_name['DeletePullToPushTaskResponse']
_UPDATEDENYCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDenyConfigResponse']
_DESCRIBEDENYCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['DescribeDenyConfigResponse']
_DELETEDENYCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDenyConfigResponse']
CreateDomainResponse = _reflection.GeneratedProtocolMessageType('CreateDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOMAINRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.CreateDomainResponse)
  })
_sym_db.RegisterMessage(CreateDomainResponse)

ListDomainDetailResponse = _reflection.GeneratedProtocolMessageType('ListDomainDetailResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDOMAINDETAILRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.ListDomainDetailResponse)
  })
_sym_db.RegisterMessage(ListDomainDetailResponse)

DisableDomainResponse = _reflection.GeneratedProtocolMessageType('DisableDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEDOMAINRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DisableDomainResponse)
  })
_sym_db.RegisterMessage(DisableDomainResponse)

EnableDomainResponse = _reflection.GeneratedProtocolMessageType('EnableDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEDOMAINRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.EnableDomainResponse)
  })
_sym_db.RegisterMessage(EnableDomainResponse)

DeleteDomainResponse = _reflection.GeneratedProtocolMessageType('DeleteDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDOMAINRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DeleteDomainResponse)
  })
_sym_db.RegisterMessage(DeleteDomainResponse)

DescribeDomainResponse = _reflection.GeneratedProtocolMessageType('DescribeDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDOMAINRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeDomainResponse)
  })
_sym_db.RegisterMessage(DescribeDomainResponse)

ManagerPullPushDomainBindResponse = _reflection.GeneratedProtocolMessageType('ManagerPullPushDomainBindResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGERPULLPUSHDOMAINBINDRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.ManagerPullPushDomainBindResponse)
  })
_sym_db.RegisterMessage(ManagerPullPushDomainBindResponse)

DescribeLiveStreamInfoByPageResponse = _reflection.GeneratedProtocolMessageType('DescribeLiveStreamInfoByPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELIVESTREAMINFOBYPAGERESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeLiveStreamInfoByPageResponse)
  })
_sym_db.RegisterMessage(DescribeLiveStreamInfoByPageResponse)

DescribeClosedStreamInfoByPageResponse = _reflection.GeneratedProtocolMessageType('DescribeClosedStreamInfoByPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECLOSEDSTREAMINFOBYPAGERESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeClosedStreamInfoByPageResponse)
  })
_sym_db.RegisterMessage(DescribeClosedStreamInfoByPageResponse)

DescribeLiveStreamStateResponse = _reflection.GeneratedProtocolMessageType('DescribeLiveStreamStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELIVESTREAMSTATERESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeLiveStreamStateResponse)
  })
_sym_db.RegisterMessage(DescribeLiveStreamStateResponse)

KillStreamResponse = _reflection.GeneratedProtocolMessageType('KillStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _KILLSTREAMRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.KillStreamResponse)
  })
_sym_db.RegisterMessage(KillStreamResponse)

ForbidStreamResponse = _reflection.GeneratedProtocolMessageType('ForbidStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _FORBIDSTREAMRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.ForbidStreamResponse)
  })
_sym_db.RegisterMessage(ForbidStreamResponse)

DescribeForbiddenStreamInfoByPageResponse = _reflection.GeneratedProtocolMessageType('DescribeForbiddenStreamInfoByPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEFORBIDDENSTREAMINFOBYPAGERESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeForbiddenStreamInfoByPageResponse)
  })
_sym_db.RegisterMessage(DescribeForbiddenStreamInfoByPageResponse)

ResumeStreamResponse = _reflection.GeneratedProtocolMessageType('ResumeStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMESTREAMRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.ResumeStreamResponse)
  })
_sym_db.RegisterMessage(ResumeStreamResponse)

DescribeCDNSnapshotHistoryResponse = _reflection.GeneratedProtocolMessageType('DescribeCDNSnapshotHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECDNSNAPSHOTHISTORYRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeCDNSnapshotHistoryResponse)
  })
_sym_db.RegisterMessage(DescribeCDNSnapshotHistoryResponse)

DescribeRecordTaskFileHistoryResponse = _reflection.GeneratedProtocolMessageType('DescribeRecordTaskFileHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERECORDTASKFILEHISTORYRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeRecordTaskFileHistoryResponse)
  })
_sym_db.RegisterMessage(DescribeRecordTaskFileHistoryResponse)

UpdateRelaySourceResponse = _reflection.GeneratedProtocolMessageType('UpdateRelaySourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERELAYSOURCERESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.UpdateRelaySourceResponse)
  })
_sym_db.RegisterMessage(UpdateRelaySourceResponse)

DeleteRelaySourceResponse = _reflection.GeneratedProtocolMessageType('DeleteRelaySourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERELAYSOURCERESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DeleteRelaySourceResponse)
  })
_sym_db.RegisterMessage(DeleteRelaySourceResponse)

DescribeRelaySourceResponse = _reflection.GeneratedProtocolMessageType('DescribeRelaySourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERELAYSOURCERESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeRelaySourceResponse)
  })
_sym_db.RegisterMessage(DescribeRelaySourceResponse)

CreateVQScoreTaskResponse = _reflection.GeneratedProtocolMessageType('CreateVQScoreTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVQSCORETASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.CreateVQScoreTaskResponse)
  })
_sym_db.RegisterMessage(CreateVQScoreTaskResponse)

DescribeVQScoreTaskResponse = _reflection.GeneratedProtocolMessageType('DescribeVQScoreTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVQSCORETASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeVQScoreTaskResponse)
  })
_sym_db.RegisterMessage(DescribeVQScoreTaskResponse)

ListVQScoreTaskResponse = _reflection.GeneratedProtocolMessageType('ListVQScoreTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVQSCORETASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.ListVQScoreTaskResponse)
  })
_sym_db.RegisterMessage(ListVQScoreTaskResponse)

GeneratePlayURLResponse = _reflection.GeneratedProtocolMessageType('GeneratePlayURLResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEPLAYURLRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.GeneratePlayURLResponse)
  })
_sym_db.RegisterMessage(GeneratePlayURLResponse)

GeneratePushURLResponse = _reflection.GeneratedProtocolMessageType('GeneratePushURLResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEPUSHURLRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.GeneratePushURLResponse)
  })
_sym_db.RegisterMessage(GeneratePushURLResponse)

CreatePullToPushTaskResponse = _reflection.GeneratedProtocolMessageType('CreatePullToPushTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPULLTOPUSHTASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.CreatePullToPushTaskResponse)
  })
_sym_db.RegisterMessage(CreatePullToPushTaskResponse)

ListPullToPushTaskResponse = _reflection.GeneratedProtocolMessageType('ListPullToPushTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPULLTOPUSHTASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.ListPullToPushTaskResponse)
  })
_sym_db.RegisterMessage(ListPullToPushTaskResponse)

UpdatePullToPushTaskResponse = _reflection.GeneratedProtocolMessageType('UpdatePullToPushTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPULLTOPUSHTASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.UpdatePullToPushTaskResponse)
  })
_sym_db.RegisterMessage(UpdatePullToPushTaskResponse)

RestartPullToPushTaskResponse = _reflection.GeneratedProtocolMessageType('RestartPullToPushTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTPULLTOPUSHTASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.RestartPullToPushTaskResponse)
  })
_sym_db.RegisterMessage(RestartPullToPushTaskResponse)

StopPullToPushTaskResponse = _reflection.GeneratedProtocolMessageType('StopPullToPushTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPPULLTOPUSHTASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.StopPullToPushTaskResponse)
  })
_sym_db.RegisterMessage(StopPullToPushTaskResponse)

DeletePullToPushTaskResponse = _reflection.GeneratedProtocolMessageType('DeletePullToPushTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPULLTOPUSHTASKRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DeletePullToPushTaskResponse)
  })
_sym_db.RegisterMessage(DeletePullToPushTaskResponse)

UpdateDenyConfigResponse = _reflection.GeneratedProtocolMessageType('UpdateDenyConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDENYCONFIGRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.UpdateDenyConfigResponse)
  })
_sym_db.RegisterMessage(UpdateDenyConfigResponse)

DescribeDenyConfigResponse = _reflection.GeneratedProtocolMessageType('DescribeDenyConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDENYCONFIGRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DescribeDenyConfigResponse)
  })
_sym_db.RegisterMessage(DescribeDenyConfigResponse)

DeleteDenyConfigResponse = _reflection.GeneratedProtocolMessageType('DeleteDenyConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDENYCONFIGRESPONSE,
  '__module__' : 'live.response.response_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Response.DeleteDenyConfigResponse)
  })
_sym_db.RegisterMessage(DeleteDenyConfigResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.responseB\014LiveResponseP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/response\240\001\001\330\001\001\312\002!Volc\\Service\\Live\\Models\\Response\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _CREATEDOMAINRESPONSE._serialized_start=378
  _CREATEDOMAINRESPONSE._serialized_end=473
  _LISTDOMAINDETAILRESPONSE._serialized_start=476
  _LISTDOMAINDETAILRESPONSE._serialized_end=640
  _DISABLEDOMAINRESPONSE._serialized_start=642
  _DISABLEDOMAINRESPONSE._serialized_end=738
  _ENABLEDOMAINRESPONSE._serialized_start=740
  _ENABLEDOMAINRESPONSE._serialized_end=835
  _DELETEDOMAINRESPONSE._serialized_start=837
  _DELETEDOMAINRESPONSE._serialized_end=932
  _DESCRIBEDOMAINRESPONSE._serialized_start=935
  _DESCRIBEDOMAINRESPONSE._serialized_end=1097
  _MANAGERPULLPUSHDOMAINBINDRESPONSE._serialized_start=1099
  _MANAGERPULLPUSHDOMAINBINDRESPONSE._serialized_end=1207
  _DESCRIBELIVESTREAMINFOBYPAGERESPONSE._serialized_start=1210
  _DESCRIBELIVESTREAMINFOBYPAGERESPONSE._serialized_end=1386
  _DESCRIBECLOSEDSTREAMINFOBYPAGERESPONSE._serialized_start=1389
  _DESCRIBECLOSEDSTREAMINFOBYPAGERESPONSE._serialized_end=1569
  _DESCRIBELIVESTREAMSTATERESPONSE._serialized_start=1572
  _DESCRIBELIVESTREAMSTATERESPONSE._serialized_end=1744
  _KILLSTREAMRESPONSE._serialized_start=1746
  _KILLSTREAMRESPONSE._serialized_end=1839
  _FORBIDSTREAMRESPONSE._serialized_start=1841
  _FORBIDSTREAMRESPONSE._serialized_end=1936
  _DESCRIBEFORBIDDENSTREAMINFOBYPAGERESPONSE._serialized_start=1939
  _DESCRIBEFORBIDDENSTREAMINFOBYPAGERESPONSE._serialized_end=2125
  _RESUMESTREAMRESPONSE._serialized_start=2127
  _RESUMESTREAMRESPONSE._serialized_end=2222
  _DESCRIBECDNSNAPSHOTHISTORYRESPONSE._serialized_start=2225
  _DESCRIBECDNSNAPSHOTHISTORYRESPONSE._serialized_end=2407
  _DESCRIBERECORDTASKFILEHISTORYRESPONSE._serialized_start=2410
  _DESCRIBERECORDTASKFILEHISTORYRESPONSE._serialized_end=2590
  _UPDATERELAYSOURCERESPONSE._serialized_start=2592
  _UPDATERELAYSOURCERESPONSE._serialized_end=2692
  _DELETERELAYSOURCERESPONSE._serialized_start=2694
  _DELETERELAYSOURCERESPONSE._serialized_end=2794
  _DESCRIBERELAYSOURCERESPONSE._serialized_start=2797
  _DESCRIBERELAYSOURCERESPONSE._serialized_end=2971
  _CREATEVQSCORETASKRESPONSE._serialized_start=2974
  _CREATEVQSCORETASKRESPONSE._serialized_end=3134
  _DESCRIBEVQSCORETASKRESPONSE._serialized_start=3137
  _DESCRIBEVQSCORETASKRESPONSE._serialized_end=3301
  _LISTVQSCORETASKRESPONSE._serialized_start=3304
  _LISTVQSCORETASKRESPONSE._serialized_end=3472
  _GENERATEPLAYURLRESPONSE._serialized_start=3475
  _GENERATEPLAYURLRESPONSE._serialized_end=3645
  _GENERATEPUSHURLRESPONSE._serialized_start=3648
  _GENERATEPUSHURLRESPONSE._serialized_end=3818
  _CREATEPULLTOPUSHTASKRESPONSE._serialized_start=3821
  _CREATEPULLTOPUSHTASKRESPONSE._serialized_end=4001
  _LISTPULLTOPUSHTASKRESPONSE._serialized_start=4004
  _LISTPULLTOPUSHTASKRESPONSE._serialized_end=4180
  _UPDATEPULLTOPUSHTASKRESPONSE._serialized_start=4182
  _UPDATEPULLTOPUSHTASKRESPONSE._serialized_end=4285
  _RESTARTPULLTOPUSHTASKRESPONSE._serialized_start=4287
  _RESTARTPULLTOPUSHTASKRESPONSE._serialized_end=4391
  _STOPPULLTOPUSHTASKRESPONSE._serialized_start=4393
  _STOPPULLTOPUSHTASKRESPONSE._serialized_end=4494
  _DELETEPULLTOPUSHTASKRESPONSE._serialized_start=4496
  _DELETEPULLTOPUSHTASKRESPONSE._serialized_end=4599
  _UPDATEDENYCONFIGRESPONSE._serialized_start=4601
  _UPDATEDENYCONFIGRESPONSE._serialized_end=4700
  _DESCRIBEDENYCONFIGRESPONSE._serialized_start=4703
  _DESCRIBEDENYCONFIGRESPONSE._serialized_end=4879
  _DELETEDENYCONFIGRESPONSE._serialized_start=4881
  _DELETEDENYCONFIGRESPONSE._serialized_end=4980
# @@protoc_insertion_point(module_scope)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import json
from json import JSONDecodeError

from requests import Response

from volcengine.tls.const import *


class TLSException(Exception):
    def __init__(self, response: Response = None, error_code: str = None, error_message: str = None):
        if response is not None:
            self.http_code = response.status_code
            self.response_header = response.headers
            self.request_id = response.headers.get(X_TLS_REQUEST_ID)

            try:
                response_body = json.loads(response.text)
                self.error_code = response_body["ErrorCode"]
                self.error_message = response_body["ErrorMessage"]
            except JSONDecodeError:
                self.error_code = response.text
                self.error_message = response.text
        else:
            self.error_code = error_code
            self.error_message = error_message

    def __str__(self):
        exception_info = "Detailed exception information is listed below."

        if "request_id" in self.__dict__:
            exception_info += "\nRequestId: {}\nHTTP status code: {}".format(self.request_id, self.http_code)

        exception_info += "\nErrorCode: {}\nErrorMessage: {}".format(self.error_code, self.error_message)

        return exception_info



# coding:utf-8
from __future__ import print_function
from volcengine.imagex.data.ImageXData import *
from volcengine.imagex.ImageXService import ImageXService

if __name__ == '__main__':
    imagex_service = ImageXService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    imagex_service.set_ak('ak')
    imagex_service.set_sk('sk')

    query = dict()
    query['StartTime'] = "2023-01-21T00:00:00+08:00"
    query['EndTime'] = "2023-01-28T00:00:00+08:00"
    query['Interval'] = "300"

    resp = describe_imagex_hit_rate_traffic_data(imagex_service, query)
    print(resp)



# coding:utf-8
from __future__ import print_function

import base64
import json

from volcengine.const.Const import *
from volcengine.sms.SmsService import SmsService

if __name__ == '__main__':
    # base64 encode func
    def to_base64_str(file):
        with open(file, 'rb') as fileObj:
            image_data = fileObj.read()
            return base64.b64encode(image_data).decode('utf-8')


    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)
    # cn
    sms_service = SmsService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_scheme("http")
    # sms_service.set_scheme("https")
    # sms_service.set_host('host')
    body = {
        "SubAccount": "subAccount",
        "TemplateId": "templateId"
    }

    resp = sms_service.get_vms_template_status(body)
    print(resp)



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.request_live_pb2 import DescribeCDNSnapshotHistoryRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    req = DescribeCDNSnapshotHistoryRequest()
    req.Vhost = 'Vhost'
    req.App = 'App'
    req.Stream = 'Stream'
    req.DateFrom = '2022-10-16T00:00:00+08:00'
    req.DateTo = '2022-10-21T23:59:59+08:00'
    req.Type = 'Type'
    req.PageNum = 0
    req.PageSize = 0
    print(req)
    resp = live_service.describe_c_d_n_snapshot_history(req)
    print(resp)




# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo

SERVICE_VERSION = "2022-01-01"

class BillingService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(BillingService, "_instance"):
            with BillingService._instance_lock:
                if not hasattr(BillingService, "_instance"):
                    BillingService._instance = object.__new__(cls)
        return BillingService._instance

    def __init__(self):
        self.service_info = BillingService.get_service_info()
        self.api_info = BillingService.get_api_info()
        super(BillingService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("billing.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'billing', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {"ListBill": ApiInfo("POST", "/", {"Action": "ListBill", "Version": SERVICE_VERSION}, {}, {}),
                    "ListBillDetail": ApiInfo("POST", "/", {"Action": "ListBillDetail", "Version": SERVICE_VERSION}, {}, {}),
                    "ListBillOverviewByProd": ApiInfo("POST", "/", {"Action": "ListBillOverviewByProd", "Version": SERVICE_VERSION}, {}, {})}
        return api_info

    def list_bill(self, params, body):
        res = self.json("ListBill", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_bill_detail(self, params, body):
        res = self.json("ListBillDetail", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_bill_overview_by_prod(self, params, body):
        res = self.json("ListBillOverviewByProd", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.request_live_pb2 import StopPullToPushTaskRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    req = StopPullToPushTaskRequest()
    req.TaskId = 'TaskId'
    print(req)
    resp = live_service.stop_pull_to_push_task(req)
    print(resp)


# coding:utf-8
from volcengine.vms.NumberPoolService import NumberPoolService

if __name__ == '__main__':
    numberPoolService = NumberPoolService()

    numberPoolService.set_ak("your ak")
    numberPoolService.set_sk("your sk")

    form = {
        "ServiceType": 100,
        "SubServiceType": 101,
        "Limit": 5,
        "Offset":0
    }
    print(numberPoolService.number_pool_list(form))



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.request_live_pb2 import DescribeLiveStreamStateRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    req = DescribeLiveStreamStateRequest()
    req.Vhost = 'Vhost'
    req.App = 'App'
    req.Stream = 'Stream'
    print(req)
    resp = live_service.describe_live_stream_state(req)
    print(resp)




# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.live_requests import ListVQScoreTaskRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    req = ListVQScoreTaskRequest()
    req.StartTime = ''
    req.EndTime = ''
    # req.PageNum = 0
    # req.PageSize = 0
    req.Status = 0

    print(req)
    resp = live_service.list_v_q_score_task(req)
    print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/index_m3u8.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1elive/business/index_m3u8.proto\x12\x1fVolcengine.Live.Models.Business\"\xfd\x01\n&CreateLiveStreamRecordIndexFilesResult\x12\x0e\n\x06\x44omain\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\x12\x0e\n\x06Stream\x18\x03 \x01(\t\x12\x11\n\tStartTime\x18\x04 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x05 \x01(\t\x12\x14\n\x0cOutputBucket\x18\x06 \x01(\t\x12\x14\n\x0cOutputObject\x18\x07 \x01(\t\x12\x11\n\tRecordURL\x18\x08 \x01(\t\x12\x10\n\x08\x44uration\x18\t \x01(\x01\x12\x0e\n\x06Height\x18\n \x01(\x03\x12\r\n\x05Width\x18\x0b \x01(\x03\x12\x12\n\nCreateTime\x18\x0c \x01(\tB\xcc\x01\n*com.volcengine.service.live.model.businessB\x04\x41\x64\x64rP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_CREATELIVESTREAMRECORDINDEXFILESRESULT = DESCRIPTOR.message_types_by_name['CreateLiveStreamRecordIndexFilesResult']
CreateLiveStreamRecordIndexFilesResult = _reflection.GeneratedProtocolMessageType('CreateLiveStreamRecordIndexFilesResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATELIVESTREAMRECORDINDEXFILESRESULT,
  '__module__' : 'live.business.index_m3u8_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.CreateLiveStreamRecordIndexFilesResult)
  })
_sym_db.RegisterMessage(CreateLiveStreamRecordIndexFilesResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\004AddrP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _CREATELIVESTREAMRECORDINDEXFILESRESULT._serialized_start=68
  _CREATELIVESTREAMRECORDINDEXFILESRESULT._serialized_end=321
# @@protoc_insertion_point(module_scope)
